# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import DownloadExportedAgreementsInCSVResponse
from ..models import ErrorEntity
from ..models import InitiateExportAgreementsToCSVResponse
from ..models import PagedRetrieveUserAcceptedAgreementResponse
from ..models import RetrieveAcceptedAgreementResponse
from ..models import UserAgreementsResponse
from ..models import UsersAgreementsRequest

from ..operations.agreement_with_namespace import DownloadExportedAgreementsInCSV
from ..operations.agreement_with_namespace import InitiateExportAgreementsToCSV
from ..operations.agreement_with_namespace import RetrieveAcceptedAgreements
from ..operations.agreement_with_namespace import (
    RetrieveAcceptedAgreementsForMultiUsers,
)
from ..operations.agreement_with_namespace import RetrieveAllUsersByPolicyVersion


@same_doc_as(DownloadExportedAgreementsInCSV)
def download_exported_agreements_in_csv(
    export_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Download Exported Users Accepted Agreements in CSV (downloadExportedAgreementsInCSV)

    This API will check the status of export process.
    If the export process has been completed, the response body will include the download url.

    Properties:
        url: /agreement/admin/namespaces/{namespace}/agreements/policy-versions/users/export-csv/download

        method: GET

        tags: ["Agreement With Namespace"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        export_id: (exportId) REQUIRED str in query

    Responses:
        200: OK - DownloadExportedAgreementsInCSVResponse (successful operation)

        404: Not Found - ErrorEntity (40047: Exported agreements for exportId [{exportId}] not found)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = DownloadExportedAgreementsInCSV.create(
        export_id=export_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DownloadExportedAgreementsInCSV)
async def download_exported_agreements_in_csv_async(
    export_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Download Exported Users Accepted Agreements in CSV (downloadExportedAgreementsInCSV)

    This API will check the status of export process.
    If the export process has been completed, the response body will include the download url.

    Properties:
        url: /agreement/admin/namespaces/{namespace}/agreements/policy-versions/users/export-csv/download

        method: GET

        tags: ["Agreement With Namespace"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        export_id: (exportId) REQUIRED str in query

    Responses:
        200: OK - DownloadExportedAgreementsInCSVResponse (successful operation)

        404: Not Found - ErrorEntity (40047: Exported agreements for exportId [{exportId}] not found)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = DownloadExportedAgreementsInCSV.create(
        export_id=export_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(InitiateExportAgreementsToCSV)
def initiate_export_agreements_to_csv(
    policy_version_id: str,
    start: str,
    end: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Initiate Export Users Accepted Agreements to CSV (initiateExportAgreementsToCSV)

    This API will initiate a worker to export list of users who has accepted a specific policy version into a CSV file.
    To check the export state after initialize it, use `GET /admin/namespaces/{namespace}/agreements/policy-versions/users/export-csv/download` API.

    This Initiate API is not allow multiple export worker running for the same namespace, it will return 409 http error if so.

    Properties:
        url: /agreement/admin/namespaces/{namespace}/agreements/policy-versions/users/export-csv/initiate

        method: POST

        tags: ["Agreement With Namespace"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        end: (end) OPTIONAL str in query

        policy_version_id: (policyVersionId) REQUIRED str in query

        start: (start) REQUIRED str in query

    Responses:
        200: OK - InitiateExportAgreementsToCSVResponse (successful operation)

        400: Bad Request - ErrorEntity (40027: Too many export running currently)

        404: Not Found - ErrorEntity (40045: Policy version with id: [{policyVersionId}] not found on namespace [{namespace}])

        409: Conflict - ErrorEntity (40071: Previous export still running for namespace [{namespace}] with exportId [{exportId}])
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = InitiateExportAgreementsToCSV.create(
        policy_version_id=policy_version_id,
        start=start,
        end=end,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(InitiateExportAgreementsToCSV)
async def initiate_export_agreements_to_csv_async(
    policy_version_id: str,
    start: str,
    end: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Initiate Export Users Accepted Agreements to CSV (initiateExportAgreementsToCSV)

    This API will initiate a worker to export list of users who has accepted a specific policy version into a CSV file.
    To check the export state after initialize it, use `GET /admin/namespaces/{namespace}/agreements/policy-versions/users/export-csv/download` API.

    This Initiate API is not allow multiple export worker running for the same namespace, it will return 409 http error if so.

    Properties:
        url: /agreement/admin/namespaces/{namespace}/agreements/policy-versions/users/export-csv/initiate

        method: POST

        tags: ["Agreement With Namespace"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        end: (end) OPTIONAL str in query

        policy_version_id: (policyVersionId) REQUIRED str in query

        start: (start) REQUIRED str in query

    Responses:
        200: OK - InitiateExportAgreementsToCSVResponse (successful operation)

        400: Bad Request - ErrorEntity (40027: Too many export running currently)

        404: Not Found - ErrorEntity (40045: Policy version with id: [{policyVersionId}] not found on namespace [{namespace}])

        409: Conflict - ErrorEntity (40071: Previous export still running for namespace [{namespace}] with exportId [{exportId}])
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = InitiateExportAgreementsToCSV.create(
        policy_version_id=policy_version_id,
        start=start,
        end=end,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(RetrieveAcceptedAgreements)
def retrieve_accepted_agreements(
    user_id: str,
    exclude_other_namespaces_policies: Optional[bool] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Retrieve Accepted Legal Agreements (retrieveAcceptedAgreements)

    This API will return all accepted Legal Agreements for specified user.

    Properties:
        url: /agreement/admin/namespaces/{namespace}/agreements/policies/users/{userId}

        method: GET

        tags: ["Agreement With Namespace"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        exclude_other_namespaces_policies: (excludeOtherNamespacesPolicies) OPTIONAL bool in query

    Responses:
        200: OK - List[RetrieveAcceptedAgreementResponse] (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = RetrieveAcceptedAgreements.create(
        user_id=user_id,
        exclude_other_namespaces_policies=exclude_other_namespaces_policies,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(RetrieveAcceptedAgreements)
async def retrieve_accepted_agreements_async(
    user_id: str,
    exclude_other_namespaces_policies: Optional[bool] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Retrieve Accepted Legal Agreements (retrieveAcceptedAgreements)

    This API will return all accepted Legal Agreements for specified user.

    Properties:
        url: /agreement/admin/namespaces/{namespace}/agreements/policies/users/{userId}

        method: GET

        tags: ["Agreement With Namespace"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        exclude_other_namespaces_policies: (excludeOtherNamespacesPolicies) OPTIONAL bool in query

    Responses:
        200: OK - List[RetrieveAcceptedAgreementResponse] (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = RetrieveAcceptedAgreements.create(
        user_id=user_id,
        exclude_other_namespaces_policies=exclude_other_namespaces_policies,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(RetrieveAcceptedAgreementsForMultiUsers)
def retrieve_accepted_agreements_for_multi_users(
    body: Optional[UsersAgreementsRequest] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Retrieve Accepted Legal Agreements For Multi Users (retrieveAcceptedAgreementsForMultiUsers)

    This API will return all accepted Legal Agreements for each user, including agreements of game users if publisher user has corresponding game account.

    Properties:
        url: /agreement/admin/namespaces/{namespace}/agreements

        method: POST

        tags: ["Agreement With Namespace"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL UsersAgreementsRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - List[UserAgreementsResponse] (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = RetrieveAcceptedAgreementsForMultiUsers.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(RetrieveAcceptedAgreementsForMultiUsers)
async def retrieve_accepted_agreements_for_multi_users_async(
    body: Optional[UsersAgreementsRequest] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Retrieve Accepted Legal Agreements For Multi Users (retrieveAcceptedAgreementsForMultiUsers)

    This API will return all accepted Legal Agreements for each user, including agreements of game users if publisher user has corresponding game account.

    Properties:
        url: /agreement/admin/namespaces/{namespace}/agreements

        method: POST

        tags: ["Agreement With Namespace"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL UsersAgreementsRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - List[UserAgreementsResponse] (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = RetrieveAcceptedAgreementsForMultiUsers.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(RetrieveAllUsersByPolicyVersion)
def retrieve_all_users_by_policy_version(
    policy_version_id: str,
    convert_game_user_id: Optional[bool] = None,
    keyword: Optional[str] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Retrieve Users Accepting Legal Agreements (retrieveAllUsersByPolicyVersion)

    This API will return all users who has accepted a specific policy version.

    Properties:
        url: /agreement/admin/namespaces/{namespace}/agreements/policy-versions/users

        method: GET

        tags: ["Agreement With Namespace"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        convert_game_user_id: (convertGameUserId) OPTIONAL bool in query

        keyword: (keyword) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        policy_version_id: (policyVersionId) REQUIRED str in query

    Responses:
        200: OK - PagedRetrieveUserAcceptedAgreementResponse (successful operation)

        404: Not Found - ErrorEntity (40035: errors.net.accelbyte.platform.legal.policy_version_not_found)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = RetrieveAllUsersByPolicyVersion.create(
        policy_version_id=policy_version_id,
        convert_game_user_id=convert_game_user_id,
        keyword=keyword,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(RetrieveAllUsersByPolicyVersion)
async def retrieve_all_users_by_policy_version_async(
    policy_version_id: str,
    convert_game_user_id: Optional[bool] = None,
    keyword: Optional[str] = None,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Retrieve Users Accepting Legal Agreements (retrieveAllUsersByPolicyVersion)

    This API will return all users who has accepted a specific policy version.

    Properties:
        url: /agreement/admin/namespaces/{namespace}/agreements/policy-versions/users

        method: GET

        tags: ["Agreement With Namespace"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        convert_game_user_id: (convertGameUserId) OPTIONAL bool in query

        keyword: (keyword) OPTIONAL str in query

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        policy_version_id: (policyVersionId) REQUIRED str in query

    Responses:
        200: OK - PagedRetrieveUserAcceptedAgreementResponse (successful operation)

        404: Not Found - ErrorEntity (40035: errors.net.accelbyte.platform.legal.policy_version_not_found)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = RetrieveAllUsersByPolicyVersion.create(
        policy_version_id=policy_version_id,
        convert_game_user_id=convert_game_user_id,
        keyword=keyword,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# Custom Service Manager

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from .utils import randomize

from ..api.csm.models import ApimodelAppDebugInfoResponse
from ..api.csm.models import ApimodelAppItem
from ..api.csm.models import ApimodelAppItemV5
from ..api.csm.models import ApimodelAppStatusProgressStep
from ..api.csm.models import ApimodelAppUIResponse
from ..api.csm.models import ApimodelApplyAppConfigRequest
from ..api.csm.models import ApimodelApplyConfigItem
from ..api.csm.models import ApimodelApplyPermissionItem
from ..api.csm.models import ApimodelAutoscalingRequest
from ..api.csm.models import ApimodelAutoscalingResponse
from ..api.csm.models import ApimodelBulkSubscribeItem
from ..api.csm.models import ApimodelBulkSubscribeRequest
from ..api.csm.models import ApimodelCPURequest
from ..api.csm.models import ApimodelCPUResponse
from ..api.csm.models import ApimodelCSMAppLimitsResponse
from ..api.csm.models import ApimodelCreateAppUIRequest
from ..api.csm.models import ApimodelCreateAppV2Request
from ..api.csm.models import ApimodelCreateAppV5Request
from ..api.csm.models import ApimodelCreateDeploymentV2Request
from ..api.csm.models import ApimodelCreateDeploymentV2Response
from ..api.csm.models import ApimodelCreateKeyValueCredentialRequest
from ..api.csm.models import ApimodelCreateKeyValueCredentialResponse
from ..api.csm.models import ApimodelCreateNoSQLAppDatabaseRequest
from ..api.csm.models import ApimodelCreateNoSQLDatabaseCredentialRequest
from ..api.csm.models import ApimodelCreateSQLAppDatabaseRequest
from ..api.csm.models import ApimodelCreateSQLDatabaseCredentialRequest
from ..api.csm.models import ApimodelCreateSubscriptionRequest
from ..api.csm.models import ApimodelCreateSubscriptionResponse
from ..api.csm.models import ApimodelCreateTopicRequest
from ..api.csm.models import ApimodelDeleteNoSQLResourceResponse
from ..api.csm.models import ApimodelDeleteSQLResourceResponse
from ..api.csm.models import ApimodelGetAppImageListV2DataItem
from ..api.csm.models import ApimodelGetAppImageListV2DataItemImageScanResult
from ..api.csm.models import ApimodelGetAppImageListV2DataItemImageScanStatus
from ..api.csm.models import ApimodelGetAppImageListV2Response
from ..api.csm.models import ApimodelGetAppListV2Request
from ..api.csm.models import ApimodelGetAppListV2Response
from ..api.csm.models import ApimodelGetAppStatusProgressResponse
from ..api.csm.models import ApimodelGetDeploymentListV2DataItem
from ..api.csm.models import ApimodelGetDeploymentListV2Request
from ..api.csm.models import ApimodelGetDeploymentListV2Response
from ..api.csm.models import ApimodelGetIntegrationAppKeyValueResponse
from ..api.csm.models import ApimodelGetListOfConfigurationsV2DataItem
from ..api.csm.models import ApimodelGetListOfConfigurationsV2Response
from ..api.csm.models import ApimodelGetNotificationSubscriberItem
from ..api.csm.models import ApimodelGetNotificationSubscriberItemV2
from ..api.csm.models import ApimodelGetNotificationSubscriberListResponse
from ..api.csm.models import ApimodelGetNotificationSubscriberListResponseV2
from ..api.csm.models import ApimodelGetNotificationSubscriberStatusResponse
from ..api.csm.models import ApimodelIncreaseLimitFormRequest
from ..api.csm.models import ApimodelIntegrateAppKeyValueRequest
from ..api.csm.models import ApimodelIntegrateAppKeyValueResponse
from ..api.csm.models import ApimodelIntegrationCredentialInfo
from ..api.csm.models import ApimodelIntegrationListItem
from ..api.csm.models import ApimodelKeyValueCredentialAcknowledgements
from ..api.csm.models import ApimodelKeyValueResourceListResponse
from ..api.csm.models import ApimodelKeyValueResourceResponse
from ..api.csm.models import ApimodelListAppUIResponse
from ..api.csm.models import ApimodelListIntegratedAppsKeyValueResponse
from ..api.csm.models import ApimodelListTopicsResponse
from ..api.csm.models import ApimodelMemoryRequest
from ..api.csm.models import ApimodelMemoryResponse
from ..api.csm.models import ApimodelNoSQLAppListResponse
from ..api.csm.models import ApimodelNoSQLAppResponse
from ..api.csm.models import ApimodelNoSQLDatabaseAcknowledgements
from ..api.csm.models import ApimodelNoSQLDatabaseCredentialResponse
from ..api.csm.models import ApimodelNoSQLDatabaseDeleteResponse
from ..api.csm.models import ApimodelNoSQLDatabaseResponse
from ..api.csm.models import ApimodelNoSQLResourceResponse
from ..api.csm.models import ApimodelNotificationType
from ..api.csm.models import ApimodelPaginationResponse
from ..api.csm.models import ApimodelPublicIAMClientResponse
from ..api.csm.models import ApimodelReplicaRequest
from ..api.csm.models import ApimodelReplicaResponse
from ..api.csm.models import ApimodelSQLAppListResponse
from ..api.csm.models import ApimodelSQLAppResponse
from ..api.csm.models import ApimodelSQLDatabaseAcknowledgements
from ..api.csm.models import ApimodelSQLDatabaseCredentialResponse
from ..api.csm.models import ApimodelSQLDatabaseDeleteResponse
from ..api.csm.models import ApimodelSQLDatabaseResponse
from ..api.csm.models import ApimodelSQLResourceResponse
from ..api.csm.models import ApimodelSaveConfigurationV2Request
from ..api.csm.models import ApimodelSaveConfigurationV2Response
from ..api.csm.models import ApimodelSaveSecretConfigurationV2Request
from ..api.csm.models import ApimodelSelfSubscribeNotificationRequest
from ..api.csm.models import ApimodelSubscribeNotificationRequest
from ..api.csm.models import ApimodelSubscribeNotificationResponse
from ..api.csm.models import ApimodelSubscriberItemRequest
from ..api.csm.models import ApimodelSubscriberItemResponse
from ..api.csm.models import ApimodelTopicDetailResponse
from ..api.csm.models import ApimodelTopicResponse
from ..api.csm.models import ApimodelTopicSubscription
from ..api.csm.models import ApimodelTunnelInfoResponse
from ..api.csm.models import ApimodelUpdateAppResourceRequest
from ..api.csm.models import ApimodelUpdateAppV2Request
from ..api.csm.models import ApimodelUpdateConfigurationV2Request
from ..api.csm.models import ApimodelUpdateConfigurationV2Response
from ..api.csm.models import ApimodelUpdateDebugModeRequest
from ..api.csm.models import ApimodelUpdateSecretConfigurationV2Request
from ..api.csm.models import ApimodelUploadFileResponse
from ..api.csm.models import CreateappparamsAutoscalingRequest
from ..api.csm.models import CreateappparamsCPURequest
from ..api.csm.models import CreateappparamsMemoryRequest
from ..api.csm.models import CreateappparamsReplicaRequest
from ..api.csm.models import DomainAllowedInterceptedPort
from ..api.csm.models import DomainDebugPod
from ..api.csm.models import DomainExposedService
from ..api.csm.models import DomainKeyValueClusterConfig
from ..api.csm.models import DomainKeyValueResourceConfiguration
from ..api.csm.models import DomainKeyValueUpdateConfiguration
from ..api.csm.models import GeneratedCreateAppV1Request
from ..api.csm.models import GeneratedCreateAppV1Response
from ..api.csm.models import GeneratedCreateDeploymentV1Request
from ..api.csm.models import GeneratedCreateDeploymentV1Response
from ..api.csm.models import GeneratedDeleteAppImagesV1Request
from ..api.csm.models import GeneratedGetAppImageListV1DataItem
from ..api.csm.models import GeneratedGetAppImageListV1DataItemImageScanStatus
from ..api.csm.models import GeneratedGetAppImageListV1Response
from ..api.csm.models import GeneratedGetAppListV1DataItem
from ..api.csm.models import GeneratedGetAppListV1Request
from ..api.csm.models import GeneratedGetAppListV1Response
from ..api.csm.models import GeneratedGetAppReleaseV1Response
from ..api.csm.models import GeneratedGetAppV1Response
from ..api.csm.models import GeneratedGetDeploymentListV1DataItem
from ..api.csm.models import GeneratedGetDeploymentListV1Request
from ..api.csm.models import GeneratedGetDeploymentListV1Response
from ..api.csm.models import GeneratedGetDeploymentV1Response
from ..api.csm.models import GeneratedGetListOfConfigurationsV1DataItem
from ..api.csm.models import GeneratedGetListOfConfigurationsV1Response
from ..api.csm.models import GeneratedPagination
from ..api.csm.models import GeneratedSaveConfigurationV1Request
from ..api.csm.models import GeneratedSaveConfigurationV1Response
from ..api.csm.models import GeneratedStartAppV1Request
from ..api.csm.models import GeneratedStartAppV1Response
from ..api.csm.models import GeneratedStopAppV1Request
from ..api.csm.models import GeneratedStopAppV1Response
from ..api.csm.models import GeneratedUpdateAppV1Request
from ..api.csm.models import GeneratedUpdateAppV1Response
from ..api.csm.models import GeneratedUpdateConfigurationV1Request
from ..api.csm.models import GeneratedUpdateConfigurationV1Response
from ..api.csm.models import LogAppMessageDeclaration
from ..api.csm.models import ModelCSMAutoscalingDefaults
from ..api.csm.models import ModelImageScanFinding
from ..api.csm.models import NosqlresourceNoSQLResourceConfiguration
from ..api.csm.models import ResourceaccesstunnelTunnelInfo
from ..api.csm.models import ResponseErrorResponse
from ..api.csm.models import SqlresourceSQLResourceConfiguration


def create_apimodel_app_debug_info_response_example() -> ApimodelAppDebugInfoResponse:
    instance = ApimodelAppDebugInfoResponse()
    instance.allowed_intercepted_ports = [
        create_domain_allowed_intercepted_port_example()
    ]
    instance.app_status = randomize()
    instance.debug_pods = [create_domain_debug_pod_example()]
    instance.exposed_services = [create_domain_exposed_service_example()]
    instance.is_debug_mode_enabled = randomize("bool")
    instance.is_debug_session_connected = randomize("bool")
    return instance


def create_apimodel_app_item_example() -> ApimodelAppItem:
    instance = ApimodelAppItem()
    instance.app_id = randomize("uid")
    instance.app_name = randomize()
    instance.app_status = randomize()
    instance.created_at = randomize()
    instance.enable_debug_mode = randomize("bool")
    instance.game_name = randomize()
    instance.is_resource_applied = randomize("bool")
    instance.scenario = randomize()
    instance.updated_at = randomize()
    instance.vm_sharing_configuration = randomize()
    instance.app_repo_arn = randomize()
    instance.app_repo_url = randomize("url")
    instance.autoscaling = create_apimodel_autoscaling_response_example()
    instance.base_path = randomize()
    instance.cpu = create_apimodel_cpu_response_example()
    instance.deleted_at = randomize()
    instance.deployment_created_at = randomize()
    instance.deployment_id = randomize()
    instance.deployment_image_tag = randomize()
    instance.description = randomize()
    instance.memory = create_apimodel_memory_response_example()
    instance.message = randomize()
    instance.replica = create_apimodel_replica_response_example()
    instance.service_public_url = randomize("url")
    instance.service_url = randomize("url")
    return instance


def create_apimodel_app_item_v5_example() -> ApimodelAppItemV5:
    instance = ApimodelAppItemV5()
    instance.app_id = randomize("uid")
    instance.app_name = randomize()
    instance.app_status = randomize()
    instance.created_at = randomize()
    instance.game_name = randomize()
    instance.scenario = randomize()
    instance.updated_at = randomize()
    instance.base_path = randomize()
    instance.description = randomize()
    instance.vm_sharing_configuration = randomize()
    return instance


def create_apimodel_app_status_progress_step_example() -> ApimodelAppStatusProgressStep:
    instance = ApimodelAppStatusProgressStep()
    instance.status = randomize()
    instance.step = randomize()
    instance.step_order = randomize("int", min_val=1, max_val=1000)
    instance.finished_at = randomize("date")
    instance.started_at = randomize("date")
    instance.status_message = randomize()
    return instance


def create_apimodel_app_ui_response_example() -> ApimodelAppUIResponse:
    instance = ApimodelAppUIResponse()
    instance.app_ui_id = randomize()
    instance.asset_base_path = randomize()
    instance.created_at = randomize("date")
    instance.current_file_version = randomize()
    instance.game_namespace = randomize("slug")
    instance.name = randomize()
    instance.updated_at = randomize("date")
    instance.public_iam_client = create_apimodel_public_iam_client_response_example()
    return instance


def create_apimodel_apply_app_config_request_example() -> ApimodelApplyAppConfigRequest:
    instance = ApimodelApplyAppConfigRequest()
    instance.scenario = randomize()
    instance.autoscaling = create_apimodel_autoscaling_request_example()
    instance.cpu = create_apimodel_cpu_request_example()
    instance.description = randomize()
    instance.memory = create_apimodel_memory_request_example()
    instance.permissions = [create_apimodel_apply_permission_item_example()]
    instance.replica = create_apimodel_replica_request_example()
    instance.secrets = [create_apimodel_apply_config_item_example()]
    instance.variables = [create_apimodel_apply_config_item_example()]
    instance.vm_sharing_configuration = randomize()
    return instance


def create_apimodel_apply_config_item_example() -> ApimodelApplyConfigItem:
    instance = ApimodelApplyConfigItem()
    instance.name = randomize()
    instance.value = randomize()
    return instance


def create_apimodel_apply_permission_item_example() -> ApimodelApplyPermissionItem:
    instance = ApimodelApplyPermissionItem()
    instance.action = randomize("int", min_val=1, max_val=1000)
    instance.resource = randomize()
    return instance


def create_apimodel_autoscaling_request_example() -> ApimodelAutoscalingRequest:
    instance = ApimodelAutoscalingRequest()
    instance.target_cpu_utilization_percent = randomize("int", min_val=1, max_val=1000)
    return instance


def create_apimodel_autoscaling_response_example() -> ApimodelAutoscalingResponse:
    instance = ApimodelAutoscalingResponse()
    instance.target_cpu_utilization_percent = randomize("int", min_val=1, max_val=1000)
    return instance


def create_apimodel_bulk_subscribe_item_example() -> ApimodelBulkSubscribeItem:
    instance = ApimodelBulkSubscribeItem()
    instance.notification_type = {}
    instance.email_address = randomize("email")
    instance.user_id = randomize("uid")
    return instance


def create_apimodel_bulk_subscribe_request_example() -> ApimodelBulkSubscribeRequest:
    instance = ApimodelBulkSubscribeRequest()
    instance.subscribers = [create_apimodel_bulk_subscribe_item_example()]
    return instance


def create_apimodel_cpu_request_example() -> ApimodelCPURequest:
    instance = ApimodelCPURequest()
    instance.request_cpu = randomize("int", min_val=1, max_val=1000)
    return instance


def create_apimodel_cpu_response_example() -> ApimodelCPUResponse:
    instance = ApimodelCPUResponse()
    instance.request_cpu = randomize("int", min_val=1, max_val=1000)
    instance.cpu_limit = randomize("int", min_val=1, max_val=1000)
    return instance


def create_apimodel_create_app_ui_request_example() -> ApimodelCreateAppUIRequest:
    instance = ApimodelCreateAppUIRequest()
    instance.name = randomize()
    return instance


def create_apimodel_create_app_v2_request_example() -> ApimodelCreateAppV2Request:
    instance = ApimodelCreateAppV2Request()
    instance.scenario = randomize()
    instance.autoscaling = create_apimodel_autoscaling_request_example()
    instance.cpu = create_apimodel_cpu_request_example()
    instance.description = randomize()
    instance.memory = create_apimodel_memory_request_example()
    instance.replica = create_apimodel_replica_request_example()
    instance.vm_sharing_configuration = randomize()
    return instance


def create_apimodel_create_app_v5_request_example() -> ApimodelCreateAppV5Request:
    instance = ApimodelCreateAppV5Request()
    instance.scenario = randomize()
    instance.autoscaling = create_createappparams_autoscaling_request_example()
    instance.cpu = create_createappparams_cpu_request_example()
    instance.description = randomize()
    instance.memory = create_createappparams_memory_request_example()
    instance.preferred_k8s_namespace = randomize("slug")
    instance.replica = create_createappparams_replica_request_example()
    instance.vm_sharing_configuration = randomize()
    return instance


def create_apimodel_create_deployment_v2_request_example() -> (
    ApimodelCreateDeploymentV2Request
):
    instance = ApimodelCreateDeploymentV2Request()
    instance.image_tag = randomize()
    return instance


def create_apimodel_create_deployment_v2_response_example() -> (
    ApimodelCreateDeploymentV2Response
):
    instance = ApimodelCreateDeploymentV2Response()
    instance.deployment_id = randomize()
    return instance


def create_apimodel_create_key_value_credential_request_example() -> (
    ApimodelCreateKeyValueCredentialRequest
):
    instance = ApimodelCreateKeyValueCredentialRequest()
    instance.password = randomize("password")
    instance.username = randomize("slug")
    return instance


def create_apimodel_create_key_value_credential_response_example() -> (
    ApimodelCreateKeyValueCredentialResponse
):
    instance = ApimodelCreateKeyValueCredentialResponse()
    instance.created_at = randomize()
    instance.owner = randomize()
    instance.recommended_max_age_days = randomize("int", min_val=1, max_val=1000)
    instance.username = randomize("slug")
    return instance


def create_apimodel_create_no_sql_app_database_request_example() -> (
    ApimodelCreateNoSQLAppDatabaseRequest
):
    instance = ApimodelCreateNoSQLAppDatabaseRequest()
    instance.acknowledgements = (
        create_apimodel_no_sql_database_acknowledgements_example()
    )
    instance.db_name = randomize()
    instance.password = randomize("password")
    instance.username = randomize("slug")
    return instance


def create_apimodel_create_no_sql_database_credential_request_example() -> (
    ApimodelCreateNoSQLDatabaseCredentialRequest
):
    instance = ApimodelCreateNoSQLDatabaseCredentialRequest()
    instance.acknowledgements = (
        create_apimodel_no_sql_database_acknowledgements_example()
    )
    instance.password = randomize("password")
    instance.username = randomize("slug")
    return instance


def create_apimodel_create_sql_app_database_request_example() -> (
    ApimodelCreateSQLAppDatabaseRequest
):
    instance = ApimodelCreateSQLAppDatabaseRequest()
    instance.acknowledgements = create_apimodel_sql_database_acknowledgements_example()
    instance.db_name = randomize()
    instance.password = randomize("password")
    instance.username = randomize("slug")
    return instance


def create_apimodel_create_sql_database_credential_request_example() -> (
    ApimodelCreateSQLDatabaseCredentialRequest
):
    instance = ApimodelCreateSQLDatabaseCredentialRequest()
    instance.password = randomize("password")
    instance.username = randomize("slug")
    return instance


def create_apimodel_create_subscription_request_example() -> (
    ApimodelCreateSubscriptionRequest
):
    instance = ApimodelCreateSubscriptionRequest()
    instance.topic_names = [randomize()]
    return instance


def create_apimodel_create_subscription_response_example() -> (
    ApimodelCreateSubscriptionResponse
):
    instance = ApimodelCreateSubscriptionResponse()
    instance.data = [create_apimodel_topic_subscription_example()]
    return instance


def create_apimodel_create_topic_request_example() -> ApimodelCreateTopicRequest:
    instance = ApimodelCreateTopicRequest()
    instance.topic_name = randomize()
    instance.description = randomize()
    return instance


def create_apimodel_csm_app_limits_response_example() -> ApimodelCSMAppLimitsResponse:
    instance = ApimodelCSMAppLimitsResponse()
    instance.autoscaling = create_model_csm_autoscaling_defaults_example()
    instance.extend_app_cpu_limit = randomize("int", min_val=1, max_val=1000)
    instance.extend_app_event_handler_cpu_limit = randomize(
        "int", min_val=1, max_val=1000
    )
    instance.extend_app_event_handler_memory_limit = randomize(
        "int", min_val=1, max_val=1000
    )
    instance.extend_app_memory_limit = randomize("int", min_val=1, max_val=1000)
    instance.extend_app_replica_limit = randomize("int", min_val=1, max_val=1000)
    instance.extend_app_service_extension_cpu_limit = randomize(
        "int", min_val=1, max_val=1000
    )
    instance.extend_app_service_extension_memory_limit = randomize(
        "int", min_val=1, max_val=1000
    )
    instance.extend_appe_event_handler_memory_limit = randomize(
        "int", min_val=1, max_val=1000
    )
    instance.max_subscriber_count = randomize("int", min_val=1, max_val=1000)
    return instance


def create_apimodel_delete_no_sql_resource_response_example() -> (
    ApimodelDeleteNoSQLResourceResponse
):
    instance = ApimodelDeleteNoSQLResourceResponse()
    instance.platform_name = randomize()
    instance.resource_id = randomize()
    instance.resource_name = randomize()
    instance.resource_type = randomize()
    instance.studio_name = randomize()
    return instance


def create_apimodel_delete_sql_resource_response_example() -> (
    ApimodelDeleteSQLResourceResponse
):
    instance = ApimodelDeleteSQLResourceResponse()
    instance.platform_name = randomize()
    instance.resource_id = randomize()
    instance.resource_name = randomize()
    instance.resource_type = randomize()
    instance.studio_name = randomize()
    return instance


def create_apimodel_get_app_image_list_v2_data_item_example() -> (
    ApimodelGetAppImageListV2DataItem
):
    instance = ApimodelGetAppImageListV2DataItem()
    instance.image_digest = randomize()
    instance.image_tag = randomize()
    instance.is_active = randomize("bool")
    instance.size = randomize("int", min_val=1, max_val=1000)
    instance.image_scan_result = (
        create_apimodel_get_app_image_list_v2_data_item_image_scan_result_example()
    )
    instance.image_scan_status = (
        create_apimodel_get_app_image_list_v2_data_item_image_scan_status_example()
    )
    instance.updated_at = randomize()
    return instance


def create_apimodel_get_app_image_list_v2_data_item_image_scan_result_example() -> (
    ApimodelGetAppImageListV2DataItemImageScanResult
):
    instance = ApimodelGetAppImageListV2DataItemImageScanResult()
    instance.finding_severity_counts = {}
    instance.findings = [create_model_image_scan_finding_example()]
    return instance


def create_apimodel_get_app_image_list_v2_data_item_image_scan_status_example() -> (
    ApimodelGetAppImageListV2DataItemImageScanStatus
):
    instance = ApimodelGetAppImageListV2DataItemImageScanStatus()
    instance.status = randomize()
    instance.description = randomize()
    return instance


def create_apimodel_get_app_image_list_v2_response_example() -> (
    ApimodelGetAppImageListV2Response
):
    instance = ApimodelGetAppImageListV2Response()
    instance.data = [create_apimodel_get_app_image_list_v2_data_item_example()]
    instance.vulnerability_status = randomize()
    instance.paging = create_generated_pagination_example()
    return instance


def create_apimodel_get_app_list_v2_request_example() -> ApimodelGetAppListV2Request:
    instance = ApimodelGetAppListV2Request()
    instance.app_names = [randomize()]
    instance.app_statuses = [randomize()]
    instance.fuzzy_app_name = randomize()
    instance.scenario = randomize()
    return instance


def create_apimodel_get_app_list_v2_response_example() -> ApimodelGetAppListV2Response:
    instance = ApimodelGetAppListV2Response()
    instance.data = [create_apimodel_app_item_example()]
    instance.paging = create_generated_pagination_example()
    return instance


def create_apimodel_get_app_status_progress_response_example() -> (
    ApimodelGetAppStatusProgressResponse
):
    instance = ApimodelGetAppStatusProgressResponse()
    instance.app_id = randomize("uid")
    instance.app_name = randomize()
    instance.operation_id = randomize()
    instance.steps = [create_apimodel_app_status_progress_step_example()]
    return instance


def create_apimodel_get_deployment_list_v2_data_item_example() -> (
    ApimodelGetDeploymentListV2DataItem
):
    instance = ApimodelGetDeploymentListV2DataItem()
    instance.deployment_id = randomize()
    instance.image_tag = randomize()
    instance.status = randomize()
    instance.deleted_at = randomize()
    instance.message = randomize()
    instance.updated_at = randomize()
    return instance


def create_apimodel_get_deployment_list_v2_request_example() -> (
    ApimodelGetDeploymentListV2Request
):
    instance = ApimodelGetDeploymentListV2Request()
    instance.app_ids = [randomize()]
    instance.deployment_ids = [randomize()]
    instance.statuses = [randomize()]
    return instance


def create_apimodel_get_deployment_list_v2_response_example() -> (
    ApimodelGetDeploymentListV2Response
):
    instance = ApimodelGetDeploymentListV2Response()
    instance.data = [create_apimodel_get_deployment_list_v2_data_item_example()]
    instance.paging = create_generated_pagination_example()
    return instance


def create_apimodel_get_integration_app_key_value_response_example() -> (
    ApimodelGetIntegrationAppKeyValueResponse
):
    instance = ApimodelGetIntegrationAppKeyValueResponse()
    instance.accept_key_value_secure_credential_handling = randomize("bool")
    instance.app_id = randomize("uid")
    instance.credentials = create_apimodel_integration_credential_info_example()
    instance.game_namespace = randomize("slug")
    instance.hostnames = randomize()
    instance.integration_id = randomize()
    instance.platform_name = randomize()
    instance.resource_id = randomize()
    instance.resource_status = randomize()
    instance.status = randomize()
    instance.status_message = randomize()
    return instance


def create_apimodel_get_list_of_configurations_v2_data_item_example() -> (
    ApimodelGetListOfConfigurationsV2DataItem
):
    instance = ApimodelGetListOfConfigurationsV2DataItem()
    instance.config_id = randomize()
    instance.config_name = randomize()
    instance.config_type = randomize()
    instance.deployment_status = randomize()
    instance.editable = randomize("bool")
    instance.is_hidden = randomize("bool")
    instance.value = randomize()
    instance.apply_mask = randomize("bool")
    instance.description = randomize()
    instance.source = randomize()
    return instance


def create_apimodel_get_list_of_configurations_v2_response_example() -> (
    ApimodelGetListOfConfigurationsV2Response
):
    instance = ApimodelGetListOfConfigurationsV2Response()
    instance.data = [create_apimodel_get_list_of_configurations_v2_data_item_example()]
    instance.paging = create_generated_pagination_example()
    return instance


def create_apimodel_get_notification_subscriber_item_example() -> (
    ApimodelGetNotificationSubscriberItem
):
    instance = ApimodelGetNotificationSubscriberItem()
    instance.notification_type = {}
    instance.subscription_id = randomize()
    instance.display_name = randomize("slug")
    instance.email_address = randomize("email")
    instance.user_id = randomize("uid")
    return instance


def create_apimodel_get_notification_subscriber_item_v2_example() -> (
    ApimodelGetNotificationSubscriberItemV2
):
    instance = ApimodelGetNotificationSubscriberItemV2()
    instance.notification_types = [create_apimodel_notification_type_example()]
    instance.display_name = randomize("slug")
    instance.email_address = randomize("email")
    instance.user_id = randomize("uid")
    return instance


def create_apimodel_get_notification_subscriber_list_response_example() -> (
    ApimodelGetNotificationSubscriberListResponse
):
    instance = ApimodelGetNotificationSubscriberListResponse()
    instance.max_subscriptions = randomize("int", min_val=1, max_val=1000)
    instance.subscriptions = [
        create_apimodel_get_notification_subscriber_item_example()
    ]
    return instance


def create_apimodel_get_notification_subscriber_list_response_v2_example() -> (
    ApimodelGetNotificationSubscriberListResponseV2
):
    instance = ApimodelGetNotificationSubscriberListResponseV2()
    instance.max_subscriptions = randomize("int", min_val=1, max_val=1000)
    instance.subscriptions = [
        create_apimodel_get_notification_subscriber_item_v2_example()
    ]
    return instance


def create_apimodel_get_notification_subscriber_status_response_example() -> (
    ApimodelGetNotificationSubscriberStatusResponse
):
    instance = ApimodelGetNotificationSubscriberStatusResponse()
    instance.max_subscription = randomize("int", min_val=1, max_val=1000)
    instance.notification_type = randomize()
    instance.subscribed = randomize("bool")
    instance.subscriptions_count = randomize("int", min_val=1, max_val=1000)
    instance.display_name = randomize("slug")
    instance.email_address = randomize("email")
    instance.user_id = randomize("uid")
    return instance


def create_apimodel_increase_limit_form_request_example() -> (
    ApimodelIncreaseLimitFormRequest
):
    instance = ApimodelIncreaseLimitFormRequest()
    instance.client_email = randomize()
    instance.request_reason = randomize()
    instance.preferred_limit_replica = randomize("int", min_val=1, max_val=1000)
    return instance


def create_apimodel_integrate_app_key_value_request_example() -> (
    ApimodelIntegrateAppKeyValueRequest
):
    instance = ApimodelIntegrateAppKeyValueRequest()
    instance.acknowledgements = (
        create_apimodel_key_value_credential_acknowledgements_example()
    )
    instance.password = randomize("password")
    instance.resource_id = randomize()
    instance.username = randomize("slug")
    return instance


def create_apimodel_integrate_app_key_value_response_example() -> (
    ApimodelIntegrateAppKeyValueResponse
):
    instance = ApimodelIntegrateAppKeyValueResponse()
    instance.accept_key_value_secure_credential_handling = randomize("bool")
    instance.app_id = randomize("uid")
    instance.credentials = create_apimodel_integration_credential_info_example()
    instance.game_namespace = randomize("slug")
    instance.hostnames = randomize()
    instance.integration_id = randomize()
    instance.platform_name = randomize()
    instance.resource_id = randomize()
    instance.resource_status = randomize()
    instance.scenario = randomize()
    instance.status = randomize()
    instance.status_message = randomize()
    return instance


def create_apimodel_integration_credential_info_example() -> (
    ApimodelIntegrationCredentialInfo
):
    instance = ApimodelIntegrationCredentialInfo()
    instance.created_at = randomize()
    instance.owner = randomize()
    instance.recommended_max_age_days = randomize("int", min_val=1, max_val=1000)
    instance.username = randomize("slug")
    return instance


def create_apimodel_integration_list_item_example() -> ApimodelIntegrationListItem:
    instance = ApimodelIntegrationListItem()
    instance.app_id = randomize("uid")
    instance.app_name = randomize()
    instance.created_at = randomize()
    instance.game_namespace = randomize("slug")
    instance.integration_id = randomize()
    instance.resource_id = randomize()
    instance.scenario = randomize()
    instance.status = randomize()
    instance.status_message = randomize()
    instance.studio_name = randomize()
    return instance


def create_apimodel_key_value_credential_acknowledgements_example() -> (
    ApimodelKeyValueCredentialAcknowledgements
):
    instance = ApimodelKeyValueCredentialAcknowledgements()
    instance.accept_key_value_secure_credential_handling = randomize("bool")
    return instance


def create_apimodel_key_value_resource_list_response_example() -> (
    ApimodelKeyValueResourceListResponse
):
    instance = ApimodelKeyValueResourceListResponse()
    instance.data = [create_apimodel_key_value_resource_response_example()]
    return instance


def create_apimodel_key_value_resource_response_example() -> (
    ApimodelKeyValueResourceResponse
):
    instance = ApimodelKeyValueResourceResponse()
    instance.cluster_name = randomize()
    instance.configuration = create_domain_key_value_resource_configuration_example()
    instance.engine = randomize()
    instance.hostnames = randomize()
    instance.last_rotated_at = randomize()
    instance.platform_name = randomize()
    instance.region = randomize()
    instance.resource_id = randomize()
    instance.resource_name = randomize()
    instance.resource_type = randomize()
    instance.status = randomize()
    instance.status_message = randomize()
    instance.studio_name = randomize()
    return instance


def create_apimodel_list_app_ui_response_example() -> ApimodelListAppUIResponse:
    instance = ApimodelListAppUIResponse()
    instance.data = [create_apimodel_app_ui_response_example()]
    instance.pagination = create_apimodel_pagination_response_example()
    return instance


def create_apimodel_list_integrated_apps_key_value_response_example() -> (
    ApimodelListIntegratedAppsKeyValueResponse
):
    instance = ApimodelListIntegratedAppsKeyValueResponse()
    instance.data = [create_apimodel_integration_list_item_example()]
    return instance


def create_apimodel_list_topics_response_example() -> ApimodelListTopicsResponse:
    instance = ApimodelListTopicsResponse()
    instance.data = [create_apimodel_topic_detail_response_example()]
    instance.pagination = create_apimodel_pagination_response_example()
    return instance


def create_apimodel_memory_request_example() -> ApimodelMemoryRequest:
    instance = ApimodelMemoryRequest()
    instance.request_memory = randomize("int", min_val=1, max_val=1000)
    return instance


def create_apimodel_memory_response_example() -> ApimodelMemoryResponse:
    instance = ApimodelMemoryResponse()
    instance.memory_limit = randomize("int", min_val=1, max_val=1000)
    instance.request_memory = randomize("int", min_val=1, max_val=1000)
    return instance


def create_apimodel_no_sql_app_list_response_example() -> ApimodelNoSQLAppListResponse:
    instance = ApimodelNoSQLAppListResponse()
    instance.data = [create_apimodel_no_sql_app_response_example()]
    instance.pagination = create_apimodel_pagination_response_example()
    return instance


def create_apimodel_no_sql_app_response_example() -> ApimodelNoSQLAppResponse:
    instance = ApimodelNoSQLAppResponse()
    instance.app_id = randomize("uid")
    instance.app_name = randomize()
    instance.game_name = randomize()
    instance.scenario = randomize()
    return instance


def create_apimodel_no_sql_database_acknowledgements_example() -> (
    ApimodelNoSQLDatabaseAcknowledgements
):
    instance = ApimodelNoSQLDatabaseAcknowledgements()
    instance.accept_nosql_secure_credential_handling = randomize("bool")
    return instance


def create_apimodel_no_sql_database_credential_response_example() -> (
    ApimodelNoSQLDatabaseCredentialResponse
):
    instance = ApimodelNoSQLDatabaseCredentialResponse()
    instance.created_at = randomize()
    instance.owner = randomize()
    instance.recommended_max_age_days = randomize("int", min_val=1, max_val=1000)
    instance.username = randomize("slug")
    return instance


def create_apimodel_no_sql_database_delete_response_example() -> (
    ApimodelNoSQLDatabaseDeleteResponse
):
    instance = ApimodelNoSQLDatabaseDeleteResponse()
    instance.db_id = randomize()
    instance.db_name = randomize()
    return instance


def create_apimodel_no_sql_database_response_example() -> ApimodelNoSQLDatabaseResponse:
    instance = ApimodelNoSQLDatabaseResponse()
    instance.accept_nosql_secure_credential_handling = randomize("bool")
    instance.app_id = randomize("uid")
    instance.credentials = create_apimodel_no_sql_database_credential_response_example()
    instance.db_id = randomize()
    instance.db_name = randomize()
    instance.game_namespace = randomize("slug")
    instance.hostnames = randomize()
    instance.platform_name = randomize()
    instance.resource_id = randomize()
    instance.resource_status = randomize()
    return instance


def create_apimodel_no_sql_resource_response_example() -> ApimodelNoSQLResourceResponse:
    instance = ApimodelNoSQLResourceResponse()
    instance.platform_name = randomize()
    instance.resource_id = randomize()
    instance.resource_name = randomize()
    instance.resource_type = randomize()
    instance.status = randomize()
    instance.studio_name = randomize()
    instance.configuration = (
        create_nosqlresource_no_sql_resource_configuration_example()
    )
    instance.engine_version = randomize()
    instance.hostnames = randomize()
    instance.last_rotated_at = randomize()
    instance.region = randomize()
    instance.tls_enabled = randomize("bool")
    return instance


def create_apimodel_notification_type_example() -> ApimodelNotificationType:
    instance = ApimodelNotificationType()
    instance.subcription_id = randomize()
    instance.type_ = randomize()
    return instance


def create_apimodel_pagination_response_example() -> ApimodelPaginationResponse:
    instance = ApimodelPaginationResponse()
    instance.total_data = randomize("int", min_val=1, max_val=1000)
    instance.first = randomize()
    instance.last = randomize()
    instance.next_ = randomize()
    instance.previous = randomize()
    return instance


def create_apimodel_public_iam_client_response_example() -> (
    ApimodelPublicIAMClientResponse
):
    instance = ApimodelPublicIAMClientResponse()
    instance.client_id = randomize("uid")
    instance.client_name = randomize()
    instance.redirect_uri_list = [randomize()]
    return instance


def create_apimodel_replica_request_example() -> ApimodelReplicaRequest:
    instance = ApimodelReplicaRequest()
    instance.max_replica = randomize("int", min_val=1, max_val=1000)
    instance.min_replica = randomize("int", min_val=1, max_val=1000)
    return instance


def create_apimodel_replica_response_example() -> ApimodelReplicaResponse:
    instance = ApimodelReplicaResponse()
    instance.current_replica = randomize("int", min_val=1, max_val=1000)
    instance.max_replica = randomize("int", min_val=1, max_val=1000)
    instance.min_replica = randomize("int", min_val=1, max_val=1000)
    instance.replica_limit = randomize("int", min_val=1, max_val=1000)
    instance.rollout_ready_replicas = randomize("int", min_val=1, max_val=1000)
    return instance


def create_apimodel_save_configuration_v2_request_example() -> (
    ApimodelSaveConfigurationV2Request
):
    instance = ApimodelSaveConfigurationV2Request()
    instance.config_name = randomize()
    instance.source = randomize()
    instance.value = randomize()
    instance.apply_mask = randomize("bool")
    instance.description = randomize()
    return instance


def create_apimodel_save_configuration_v2_response_example() -> (
    ApimodelSaveConfigurationV2Response
):
    instance = ApimodelSaveConfigurationV2Response()
    instance.config_id = randomize()
    instance.config_name = randomize()
    return instance


def create_apimodel_save_secret_configuration_v2_request_example() -> (
    ApimodelSaveSecretConfigurationV2Request
):
    instance = ApimodelSaveSecretConfigurationV2Request()
    instance.config_name = randomize()
    instance.source = randomize()
    instance.value = randomize()
    instance.description = randomize()
    return instance


def create_apimodel_self_subscribe_notification_request_example() -> (
    ApimodelSelfSubscribeNotificationRequest
):
    instance = ApimodelSelfSubscribeNotificationRequest()
    instance.notification_type = randomize()
    return instance


def create_apimodel_sql_app_list_response_example() -> ApimodelSQLAppListResponse:
    instance = ApimodelSQLAppListResponse()
    instance.data = [create_apimodel_sql_app_response_example()]
    instance.pagination = create_apimodel_pagination_response_example()
    return instance


def create_apimodel_sql_app_response_example() -> ApimodelSQLAppResponse:
    instance = ApimodelSQLAppResponse()
    instance.app_id = randomize("uid")
    instance.app_name = randomize()
    instance.game_name = randomize()
    instance.scenario = randomize()
    return instance


def create_apimodel_sql_database_acknowledgements_example() -> (
    ApimodelSQLDatabaseAcknowledgements
):
    instance = ApimodelSQLDatabaseAcknowledgements()
    instance.accept_sql_secure_credential_handling = randomize("bool")
    return instance


def create_apimodel_sql_database_credential_response_example() -> (
    ApimodelSQLDatabaseCredentialResponse
):
    instance = ApimodelSQLDatabaseCredentialResponse()
    instance.created_at = randomize()
    instance.owner = randomize()
    instance.recommended_max_age = randomize("int", min_val=1, max_val=1000)
    instance.username = randomize("slug")
    return instance


def create_apimodel_sql_database_delete_response_example() -> (
    ApimodelSQLDatabaseDeleteResponse
):
    instance = ApimodelSQLDatabaseDeleteResponse()
    instance.db_id = randomize()
    instance.db_name = randomize()
    return instance


def create_apimodel_sql_database_response_example() -> ApimodelSQLDatabaseResponse:
    instance = ApimodelSQLDatabaseResponse()
    instance.accept_sql_secure_credential_handling = randomize("bool")
    instance.app_id = randomize("uid")
    instance.credentials = create_apimodel_sql_database_credential_response_example()
    instance.db_id = randomize()
    instance.db_name = randomize()
    instance.game_namespace = randomize("slug")
    instance.hostnames = randomize()
    instance.platform_name = randomize()
    instance.resource_id = randomize()
    instance.resource_status = randomize()
    return instance


def create_apimodel_sql_resource_response_example() -> ApimodelSQLResourceResponse:
    instance = ApimodelSQLResourceResponse()
    instance.platform_name = randomize()
    instance.resource_id = randomize()
    instance.resource_name = randomize()
    instance.resource_type = randomize()
    instance.status = randomize()
    instance.studio_name = randomize()
    instance.configuration = create_sqlresource_sql_resource_configuration_example()
    instance.engine_version = randomize()
    instance.hostnames = randomize()
    instance.last_rotated_at = randomize()
    instance.region = randomize()
    return instance


def create_apimodel_subscribe_notification_request_example() -> (
    ApimodelSubscribeNotificationRequest
):
    instance = ApimodelSubscribeNotificationRequest()
    instance.notification_type = randomize()
    instance.subscribers = [create_apimodel_subscriber_item_request_example()]
    return instance


def create_apimodel_subscribe_notification_response_example() -> (
    ApimodelSubscribeNotificationResponse
):
    instance = ApimodelSubscribeNotificationResponse()
    instance.notification_type = randomize()
    instance.subscriptions = [create_apimodel_subscriber_item_response_example()]
    return instance


def create_apimodel_subscriber_item_request_example() -> ApimodelSubscriberItemRequest:
    instance = ApimodelSubscriberItemRequest()
    instance.email_address = randomize("email")
    instance.user_id = randomize("uid")
    return instance


def create_apimodel_subscriber_item_response_example() -> (
    ApimodelSubscriberItemResponse
):
    instance = ApimodelSubscriberItemResponse()
    instance.id_ = randomize()
    instance.display_name = randomize("slug")
    instance.email_address = randomize("email")
    instance.notification_type = randomize()
    instance.user_id = randomize("uid")
    return instance


def create_apimodel_topic_detail_response_example() -> ApimodelTopicDetailResponse:
    instance = ApimodelTopicDetailResponse()
    instance.game_name = randomize()
    instance.id_ = randomize()
    instance.region = randomize()
    instance.studio_name = randomize()
    instance.topic_arn = randomize()
    instance.topic_name = randomize()
    instance.description = randomize()
    instance.subscribers = [create_apimodel_topic_subscription_example()]
    return instance


def create_apimodel_topic_response_example() -> ApimodelTopicResponse:
    instance = ApimodelTopicResponse()
    instance.game_name = randomize()
    instance.id_ = randomize()
    instance.region = randomize()
    instance.studio_name = randomize()
    instance.topic_arn = randomize()
    instance.topic_name = randomize()
    instance.description = randomize()
    return instance


def create_apimodel_topic_subscription_example() -> ApimodelTopicSubscription:
    instance = ApimodelTopicSubscription()
    instance.app_id = randomize("uid")
    instance.app_name = randomize()
    instance.queue_id = randomize()
    instance.subscription_arn = randomize()
    instance.subscription_id = randomize()
    instance.subscription_time = randomize()
    return instance


def create_apimodel_tunnel_info_response_example() -> ApimodelTunnelInfoResponse:
    instance = ApimodelTunnelInfoResponse()
    instance.tunnel = create_resourceaccesstunnel_tunnel_info_example()
    return instance


def create_apimodel_update_app_resource_request_example() -> (
    ApimodelUpdateAppResourceRequest
):
    instance = ApimodelUpdateAppResourceRequest()
    instance.autoscaling = create_apimodel_autoscaling_request_example()
    instance.cpu = create_apimodel_cpu_request_example()
    instance.memory = create_apimodel_memory_request_example()
    instance.replica = create_apimodel_replica_request_example()
    instance.vm_sharing_configuration = randomize()
    return instance


def create_apimodel_update_app_v2_request_example() -> ApimodelUpdateAppV2Request:
    instance = ApimodelUpdateAppV2Request()
    instance.description = randomize()
    instance.enable_debug_mode = randomize("bool")
    return instance


def create_apimodel_update_configuration_v2_request_example() -> (
    ApimodelUpdateConfigurationV2Request
):
    instance = ApimodelUpdateConfigurationV2Request()
    instance.value = randomize()
    instance.apply_mask = randomize("bool")
    instance.description = randomize()
    return instance


def create_apimodel_update_configuration_v2_response_example() -> (
    ApimodelUpdateConfigurationV2Response
):
    instance = ApimodelUpdateConfigurationV2Response()
    instance.config_id = randomize()
    instance.config_name = randomize()
    instance.value = randomize()
    instance.apply_mask = randomize("bool")
    instance.description = randomize()
    instance.source = randomize()
    return instance


def create_apimodel_update_debug_mode_request_example() -> (
    ApimodelUpdateDebugModeRequest
):
    instance = ApimodelUpdateDebugModeRequest()
    instance.enable_debug_mode = randomize("bool")
    return instance


def create_apimodel_update_secret_configuration_v2_request_example() -> (
    ApimodelUpdateSecretConfigurationV2Request
):
    instance = ApimodelUpdateSecretConfigurationV2Request()
    instance.value = randomize()
    instance.description = randomize()
    return instance


def create_apimodel_upload_file_response_example() -> ApimodelUploadFileResponse:
    instance = ApimodelUploadFileResponse()
    instance.app_ui = create_apimodel_app_ui_response_example()
    return instance


def create_createappparams_autoscaling_request_example() -> (
    CreateappparamsAutoscalingRequest
):
    instance = CreateappparamsAutoscalingRequest()
    instance.target_cpu_utilization_percent = randomize("int", min_val=1, max_val=1000)
    return instance


def create_createappparams_cpu_request_example() -> CreateappparamsCPURequest:
    instance = CreateappparamsCPURequest()
    instance.request_cpu = randomize("int", min_val=1, max_val=1000)
    return instance


def create_createappparams_memory_request_example() -> CreateappparamsMemoryRequest:
    instance = CreateappparamsMemoryRequest()
    instance.request_memory = randomize("int", min_val=1, max_val=1000)
    return instance


def create_createappparams_replica_request_example() -> CreateappparamsReplicaRequest:
    instance = CreateappparamsReplicaRequest()
    instance.max_replica = randomize("int", min_val=1, max_val=1000)
    instance.min_replica = randomize("int", min_val=1, max_val=1000)
    return instance


def create_domain_allowed_intercepted_port_example() -> DomainAllowedInterceptedPort:
    instance = DomainAllowedInterceptedPort()
    instance.port = randomize("int", min_val=1, max_val=1000)
    return instance


def create_domain_debug_pod_example() -> DomainDebugPod:
    instance = DomainDebugPod()
    instance.pod_name = randomize()
    instance.port = randomize("int", min_val=1, max_val=1000)
    return instance


def create_domain_exposed_service_example() -> DomainExposedService:
    instance = DomainExposedService()
    instance.host = randomize()
    instance.name = randomize()
    instance.port = randomize("int", min_val=1, max_val=1000)
    return instance


def create_domain_key_value_cluster_config_example() -> DomainKeyValueClusterConfig:
    instance = DomainKeyValueClusterConfig()
    instance.max_cluster_per_studio_private_cloud = randomize(
        "int", min_val=1, max_val=1000
    )
    instance.max_cluster_per_studio_shared_cloud = randomize(
        "int", min_val=1, max_val=1000
    )
    instance.max_integration_per_cluster = randomize("int", min_val=1, max_val=1000)
    return instance


def create_domain_key_value_resource_configuration_example() -> (
    DomainKeyValueResourceConfiguration
):
    instance = DomainKeyValueResourceConfiguration()
    instance.cluster_name = randomize()
    instance.max_data_storage_gb = randomize("int", min_val=1, max_val=1000)
    instance.max_ecpu_per_second = randomize("int", min_val=1, max_val=1000)
    instance.profile_name = randomize()
    return instance


def create_domain_key_value_update_configuration_example() -> (
    DomainKeyValueUpdateConfiguration
):
    instance = DomainKeyValueUpdateConfiguration()
    instance.max_data_storage_gb = randomize("int", min_val=1, max_val=1000)
    instance.max_ecpu_per_second = randomize("int", min_val=1, max_val=1000)
    instance.profile_name = randomize()
    return instance


def create_generated_create_app_v1_request_example() -> GeneratedCreateAppV1Request:
    instance = GeneratedCreateAppV1Request()
    instance.description = randomize()
    instance.scenario = randomize()
    return instance


def create_generated_create_app_v1_response_example() -> GeneratedCreateAppV1Response:
    instance = GeneratedCreateAppV1Response()
    instance.status_url = randomize("url")
    return instance


def create_generated_create_deployment_v1_request_example() -> (
    GeneratedCreateDeploymentV1Request
):
    instance = GeneratedCreateDeploymentV1Request()
    instance.image_tag = randomize()
    instance.description = randomize()
    return instance


def create_generated_create_deployment_v1_response_example() -> (
    GeneratedCreateDeploymentV1Response
):
    instance = GeneratedCreateDeploymentV1Response()
    instance.deployment_id = randomize()
    return instance


def create_generated_delete_app_images_v1_request_example() -> (
    GeneratedDeleteAppImagesV1Request
):
    instance = GeneratedDeleteAppImagesV1Request()
    instance.image_tags = [randomize()]
    return instance


def create_generated_get_app_image_list_v1_data_item_example() -> (
    GeneratedGetAppImageListV1DataItem
):
    instance = GeneratedGetAppImageListV1DataItem()
    instance.image_digest = randomize()
    instance.image_tag = randomize()
    instance.image_scan_status = (
        create_generated_get_app_image_list_v1_data_item_image_scan_status_example()
    )
    instance.size = randomize("int", min_val=1, max_val=1000)
    instance.updated_at = randomize()
    return instance


def create_generated_get_app_image_list_v1_data_item_image_scan_status_example() -> (
    GeneratedGetAppImageListV1DataItemImageScanStatus
):
    instance = GeneratedGetAppImageListV1DataItemImageScanStatus()
    instance.description = randomize()
    instance.status = randomize()
    return instance


def create_generated_get_app_image_list_v1_response_example() -> (
    GeneratedGetAppImageListV1Response
):
    instance = GeneratedGetAppImageListV1Response()
    instance.data = [create_generated_get_app_image_list_v1_data_item_example()]
    instance.paging = create_generated_pagination_example()
    return instance


def create_generated_get_app_list_v1_data_item_example() -> (
    GeneratedGetAppListV1DataItem
):
    instance = GeneratedGetAppListV1DataItem()
    instance.deployment_created_at = randomize()
    instance.deployment_id = randomize()
    instance.deployment_image_tag = randomize()
    instance.app_id = randomize("uid")
    instance.app_name = randomize()
    instance.app_release_status = randomize()
    instance.app_repo_arn = randomize()
    instance.app_repo_url = randomize("url")
    instance.app_status = randomize()
    instance.base_path = randomize()
    instance.deleted_at = randomize()
    instance.deployment_status = randomize()
    instance.description = randomize()
    instance.message = randomize()
    instance.scenario = randomize()
    instance.service_public_url = randomize("url")
    instance.service_url = randomize("url")
    instance.status = randomize()
    instance.updated_at = randomize()
    return instance


def create_generated_get_app_list_v1_request_example() -> GeneratedGetAppListV1Request:
    instance = GeneratedGetAppListV1Request()
    instance.app_names = [randomize()]
    instance.statuses = [randomize()]
    instance.fuzzy_app_name = randomize()
    instance.scenario = randomize()
    return instance


def create_generated_get_app_list_v1_response_example() -> (
    GeneratedGetAppListV1Response
):
    instance = GeneratedGetAppListV1Response()
    instance.data = [create_generated_get_app_list_v1_data_item_example()]
    instance.paging = create_generated_pagination_example()
    return instance


def create_generated_get_app_release_v1_response_example() -> (
    GeneratedGetAppReleaseV1Response
):
    instance = GeneratedGetAppReleaseV1Response()
    instance.deployment_id = randomize()
    instance.image_tag = randomize()
    instance.release_date = randomize()
    return instance


def create_generated_get_app_v1_response_example() -> GeneratedGetAppV1Response:
    instance = GeneratedGetAppV1Response()
    instance.deployment_created_at = randomize()
    instance.deployment_id = randomize()
    instance.deployment_image_tag = randomize()
    instance.app_id = randomize("uid")
    instance.app_name = randomize()
    instance.app_release_status = randomize()
    instance.app_repo_arn = randomize()
    instance.app_repo_url = randomize("url")
    instance.app_status = randomize()
    instance.base_path = randomize()
    instance.created_at = randomize()
    instance.deleted_at = randomize()
    instance.deployment_status = randomize()
    instance.description = randomize()
    instance.message = randomize()
    instance.scenario = randomize()
    instance.service_public_url = randomize("url")
    instance.service_url = randomize("url")
    instance.status = randomize()
    instance.updated_at = randomize()
    return instance


def create_generated_get_deployment_list_v1_data_item_example() -> (
    GeneratedGetDeploymentListV1DataItem
):
    instance = GeneratedGetDeploymentListV1DataItem()
    instance.deployment_id = randomize()
    instance.deleted_at = randomize()
    instance.image_tag = randomize()
    instance.message = randomize()
    instance.status = randomize()
    instance.updated_at = randomize()
    return instance


def create_generated_get_deployment_list_v1_request_example() -> (
    GeneratedGetDeploymentListV1Request
):
    instance = GeneratedGetDeploymentListV1Request()
    instance.app_ids = [randomize()]
    instance.deployment_ids = [randomize()]
    instance.statuses = [randomize()]
    return instance


def create_generated_get_deployment_list_v1_response_example() -> (
    GeneratedGetDeploymentListV1Response
):
    instance = GeneratedGetDeploymentListV1Response()
    instance.data = [create_generated_get_deployment_list_v1_data_item_example()]
    instance.paging = create_generated_pagination_example()
    return instance


def create_generated_get_deployment_v1_response_example() -> (
    GeneratedGetDeploymentV1Response
):
    instance = GeneratedGetDeploymentV1Response()
    instance.deployment_id = randomize()
    instance.deleted_at = randomize()
    instance.image_tag = randomize()
    instance.message = randomize()
    instance.status = randomize()
    instance.updated_at = randomize()
    return instance


def create_generated_get_list_of_configurations_v1_data_item_example() -> (
    GeneratedGetListOfConfigurationsV1DataItem
):
    instance = GeneratedGetListOfConfigurationsV1DataItem()
    instance.apply_mask = randomize("bool")
    instance.config_id = randomize()
    instance.config_name = randomize()
    instance.config_type = randomize()
    instance.deployment_status = randomize()
    instance.description = randomize()
    instance.editable = randomize("bool")
    instance.is_hidden = randomize("bool")
    instance.source = randomize()
    instance.value = randomize()
    return instance


def create_generated_get_list_of_configurations_v1_response_example() -> (
    GeneratedGetListOfConfigurationsV1Response
):
    instance = GeneratedGetListOfConfigurationsV1Response()
    instance.data = [create_generated_get_list_of_configurations_v1_data_item_example()]
    instance.paging = create_generated_pagination_example()
    return instance


def create_generated_pagination_example() -> GeneratedPagination:
    instance = GeneratedPagination()
    instance.first = randomize()
    instance.last = randomize()
    instance.next_ = randomize()
    instance.previous = randomize()
    return instance


def create_generated_save_configuration_v1_request_example() -> (
    GeneratedSaveConfigurationV1Request
):
    instance = GeneratedSaveConfigurationV1Request()
    instance.config_name = randomize()
    instance.source = randomize()
    instance.value = randomize()
    instance.apply_mask = randomize("bool")
    instance.description = randomize()
    return instance


def create_generated_save_configuration_v1_response_example() -> (
    GeneratedSaveConfigurationV1Response
):
    instance = GeneratedSaveConfigurationV1Response()
    instance.config_id = randomize()
    instance.config_name = randomize()
    return instance


def create_generated_start_app_v1_request_example() -> GeneratedStartAppV1Request:
    instance = GeneratedStartAppV1Request()
    instance.reason = randomize()
    return instance


def create_generated_start_app_v1_response_example() -> GeneratedStartAppV1Response:
    instance = GeneratedStartAppV1Response()
    instance.status_url = randomize("url")
    return instance


def create_generated_stop_app_v1_request_example() -> GeneratedStopAppV1Request:
    instance = GeneratedStopAppV1Request()
    instance.reason = randomize()
    return instance


def create_generated_stop_app_v1_response_example() -> GeneratedStopAppV1Response:
    instance = GeneratedStopAppV1Response()
    instance.status_url = randomize("url")
    return instance


def create_generated_update_app_v1_request_example() -> GeneratedUpdateAppV1Request:
    instance = GeneratedUpdateAppV1Request()
    instance.description = randomize()
    return instance


def create_generated_update_app_v1_response_example() -> GeneratedUpdateAppV1Response:
    instance = GeneratedUpdateAppV1Response()
    instance.app_id = randomize("uid")
    instance.app_name = randomize()
    instance.app_repo_arn = randomize()
    instance.app_repo_url = randomize("url")
    instance.deleted_at = randomize()
    instance.description = randomize()
    instance.message = randomize()
    instance.scenario = randomize()
    instance.service_url = randomize("url")
    instance.status = randomize()
    instance.updated_at = randomize()
    return instance


def create_generated_update_configuration_v1_request_example() -> (
    GeneratedUpdateConfigurationV1Request
):
    instance = GeneratedUpdateConfigurationV1Request()
    instance.apply_mask = randomize("bool")
    instance.description = randomize()
    instance.value = randomize()
    return instance


def create_generated_update_configuration_v1_response_example() -> (
    GeneratedUpdateConfigurationV1Response
):
    instance = GeneratedUpdateConfigurationV1Response()
    instance.apply_mask = randomize("bool")
    instance.config_id = randomize()
    instance.config_name = randomize()
    instance.description = randomize()
    instance.source = randomize()
    instance.value = randomize()
    return instance


def create_log_app_message_declaration_example() -> LogAppMessageDeclaration:
    instance = LogAppMessageDeclaration()
    instance.attributes = [randomize()]
    instance.code = randomize()
    instance.code_name = randomize()
    instance.section = randomize()
    instance.service = randomize()
    instance.text = randomize()
    return instance


def create_model_csm_autoscaling_defaults_example() -> ModelCSMAutoscalingDefaults:
    instance = ModelCSMAutoscalingDefaults()
    instance.cpu_utilization_default_percent = randomize("int", min_val=1, max_val=1000)
    instance.cpu_utilization_max_percent = randomize("int", min_val=1, max_val=1000)
    instance.cpu_utilization_min_percent = randomize("int", min_val=1, max_val=1000)
    return instance


def create_model_image_scan_finding_example() -> ModelImageScanFinding:
    instance = ModelImageScanFinding()
    instance.name = randomize()
    instance.severity = randomize()
    instance.uri = randomize()
    instance.description = randomize()
    return instance


def create_nosqlresource_no_sql_resource_configuration_example() -> (
    NosqlresourceNoSQLResourceConfiguration
):
    instance = NosqlresourceNoSQLResourceConfiguration()
    instance.max_dcu = randomize("int", min_val=1, max_val=1000)
    instance.min_dcu = randomize("int", min_val=1, max_val=1000)
    instance.profile_name = randomize()
    return instance


def create_resourceaccesstunnel_tunnel_info_example() -> ResourceaccesstunnelTunnelInfo:
    instance = ResourceaccesstunnelTunnelInfo()
    instance.endpoint = randomize()
    instance.name = randomize()
    instance.token = randomize()
    return instance


def create_response_error_response_example() -> ResponseErrorResponse:
    instance = ResponseErrorResponse()
    instance.error = randomize()
    instance.error_code = randomize("int", min_val=1, max_val=1000)
    instance.error_message = randomize()
    instance.errors = randomize()
    instance.message_variables = {randomize(): randomize()}
    instance.name = randomize()
    instance.reason = randomize()
    return instance


def create_sqlresource_sql_resource_configuration_example() -> (
    SqlresourceSQLResourceConfiguration
):
    instance = SqlresourceSQLResourceConfiguration()
    instance.max_acu = randomize("int", min_val=1, max_val=1000)
    instance.min_acu = randomize("int", min_val=1, max_val=1000)
    instance.multi_az = randomize("bool")
    instance.profile_name = randomize()
    return instance



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import deprecated
from ....core import same_doc_as

from ..models import ErrorEntity
from ..models import PaymentCallbackConfigInfo
from ..models import PaymentCallbackConfigUpdate

from ..operations.payment_callback_config import GetPaymentCallbackConfig
from ..operations.payment_callback_config import UpdatePaymentCallbackConfig


@deprecated
@same_doc_as(GetPaymentCallbackConfig)
def get_payment_callback_config(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get payment callback configuration (getPaymentCallbackConfig)

    ### The endpoint is going to be deprecated

    [Not supported yet in AGS Shared Cloud] Get payment callback configuration.
    Other detail info:

      * Returns : Payment callback config

    Properties:
        url: /platform/admin/namespaces/{namespace}/payment/config/callback

        method: GET

        tags: ["PaymentCallbackConfig"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - PaymentCallbackConfigInfo (successful operation)

        404: Not Found - ErrorEntity (33243: Payment callback config for [{namespace}] does not exist)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = GetPaymentCallbackConfig.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(GetPaymentCallbackConfig)
async def get_payment_callback_config_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get payment callback configuration (getPaymentCallbackConfig)

    ### The endpoint is going to be deprecated

    [Not supported yet in AGS Shared Cloud] Get payment callback configuration.
    Other detail info:

      * Returns : Payment callback config

    Properties:
        url: /platform/admin/namespaces/{namespace}/payment/config/callback

        method: GET

        tags: ["PaymentCallbackConfig"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - PaymentCallbackConfigInfo (successful operation)

        404: Not Found - ErrorEntity (33243: Payment callback config for [{namespace}] does not exist)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = GetPaymentCallbackConfig.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@deprecated
@same_doc_as(UpdatePaymentCallbackConfig)
def update_payment_callback_config(
    body: PaymentCallbackConfigUpdate,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update payment callback configuration (updatePaymentCallbackConfig)

    ### The endpoint is going to be deprecated

    [Not supported yet in AGS Shared Cloud] Update payment callback configuration.
    Other detail info:

      * Returns : Payment callback config

    Properties:
        url: /platform/admin/namespaces/{namespace}/payment/config/callback

        method: PUT

        tags: ["PaymentCallbackConfig"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED PaymentCallbackConfigUpdate in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - PaymentCallbackConfigInfo (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = UpdatePaymentCallbackConfig.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(UpdatePaymentCallbackConfig)
async def update_payment_callback_config_async(
    body: PaymentCallbackConfigUpdate,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update payment callback configuration (updatePaymentCallbackConfig)

    ### The endpoint is going to be deprecated

    [Not supported yet in AGS Shared Cloud] Update payment callback configuration.
    Other detail info:

      * Returns : Payment callback config

    Properties:
        url: /platform/admin/namespaces/{namespace}/payment/config/callback

        method: PUT

        tags: ["PaymentCallbackConfig"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED PaymentCallbackConfigUpdate in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - PaymentCallbackConfigInfo (successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = UpdatePaymentCallbackConfig.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

# AccelByte Gaming Services Platform Service

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from .....core import Operation
from .....core import HeaderStr
from .....core import HttpResponse

from ...models import ErrorEntity
from ...models import ImportStoreResult


class ImportStoreByCSV(Operation):
    """Import store using CSV format (importStoreByCSV)

    This API is used to import a store by CSV format, You must select at least one of item/section/display/category for uploading

    Properties:
        url: /platform/admin/namespaces/{namespace}/stores/{storeId}/importByCSV

        method: POST

        tags: ["Store"]

        consumes: ["multipart/form-data"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        category: (category) OPTIONAL Any in form_data

        display: (display) OPTIONAL Any in form_data

        item: (item) OPTIONAL Any in form_data

        notes: (notes) OPTIONAL str in form_data

        section: (section) OPTIONAL Any in form_data

        namespace: (namespace) REQUIRED str in path

        store_id: (storeId) REQUIRED str in path

    Responses:
        200: OK - ImportStoreResult (successful operation)

        400: Bad Request - ErrorEntity (30024: Unable to parse CSV cell [{content}] | 30025: [{header}] is required by CSV import/export for catalogType [{catalogType}] | 30121: Store data is invalid)

        404: Not Found - ErrorEntity (30141: Store [{storeId}] does not exist in namespace [{namespace}] | 30142: Published store does not exist in namespace [{namespace}])

        409: Conflict - ErrorEntity (30076: CSV header [{headerName}] is not supported for CatalogType [{catalogType}] | 30382: Duplicated Item sku [{sku}])
    """

    # region fields

    _url: str = "/platform/admin/namespaces/{namespace}/stores/{storeId}/importByCSV"
    _method: str = "POST"
    _consumes: List[str] = ["multipart/form-data"]
    _produces: List[str] = ["application/json"]
    _securities: List[List[str]] = [["BEARER_AUTH"]]
    _location_query: str = None

    category: Any  # OPTIONAL in [form_data]
    display: Any  # OPTIONAL in [form_data]
    item: Any  # OPTIONAL in [form_data]
    notes: str  # OPTIONAL in [form_data]
    section: Any  # OPTIONAL in [form_data]
    namespace: str  # REQUIRED in [path]
    store_id: str  # REQUIRED in [path]

    # endregion fields

    # region properties

    @property
    def url(self) -> str:
        return self._url

    @property
    def method(self) -> str:
        return self._method

    @property
    def consumes(self) -> List[str]:
        return self._consumes

    @property
    def produces(self) -> List[str]:
        return self._produces

    @property
    def securities(self) -> List[List[str]]:
        return self._securities

    @property
    def location_query(self) -> str:
        return self._location_query

    # endregion properties

    # region get methods

    # endregion get methods

    # region get_x_params methods

    def get_all_params(self) -> dict:
        return {
            "form_data": self.get_form_data_params(),
            "path": self.get_path_params(),
        }

    def get_form_data_params(self) -> dict:
        result = {}
        if hasattr(self, "category"):
            result[("category", "file")] = self.category
        if hasattr(self, "display"):
            result[("display", "file")] = self.display
        if hasattr(self, "item"):
            result[("item", "file")] = self.item
        if hasattr(self, "notes"):
            result["notes"] = self.notes
        if hasattr(self, "section"):
            result[("section", "file")] = self.section
        return result

    def get_path_params(self) -> dict:
        result = {}
        if hasattr(self, "namespace"):
            result["namespace"] = self.namespace
        if hasattr(self, "store_id"):
            result["storeId"] = self.store_id
        return result

    # endregion get_x_params methods

    # region is/has methods

    # endregion is/has methods

    # region with_x methods

    def with_category(self, value: Any) -> ImportStoreByCSV:
        self.category = value
        return self

    def with_display(self, value: Any) -> ImportStoreByCSV:
        self.display = value
        return self

    def with_item(self, value: Any) -> ImportStoreByCSV:
        self.item = value
        return self

    def with_notes(self, value: str) -> ImportStoreByCSV:
        self.notes = value
        return self

    def with_section(self, value: Any) -> ImportStoreByCSV:
        self.section = value
        return self

    def with_namespace(self, value: str) -> ImportStoreByCSV:
        self.namespace = value
        return self

    def with_store_id(self, value: str) -> ImportStoreByCSV:
        self.store_id = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "category") and self.category:
            result["category"] = Any(self.category)
        elif include_empty:
            result["category"] = Any()
        if hasattr(self, "display") and self.display:
            result["display"] = Any(self.display)
        elif include_empty:
            result["display"] = Any()
        if hasattr(self, "item") and self.item:
            result["item"] = Any(self.item)
        elif include_empty:
            result["item"] = Any()
        if hasattr(self, "notes") and self.notes:
            result["notes"] = str(self.notes)
        elif include_empty:
            result["notes"] = ""
        if hasattr(self, "section") and self.section:
            result["section"] = Any(self.section)
        elif include_empty:
            result["section"] = Any()
        if hasattr(self, "namespace") and self.namespace:
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "store_id") and self.store_id:
            result["storeId"] = str(self.store_id)
        elif include_empty:
            result["storeId"] = ""
        return result

    # endregion to methods

    # region response methods

    # noinspection PyMethodMayBeStatic
    def parse_response(
        self, code: int, content_type: str, content: Any
    ) -> Tuple[Union[None, ImportStoreResult], Union[None, ErrorEntity, HttpResponse]]:
        """Parse the given response.

        200: OK - ImportStoreResult (successful operation)

        400: Bad Request - ErrorEntity (30024: Unable to parse CSV cell [{content}] | 30025: [{header}] is required by CSV import/export for catalogType [{catalogType}] | 30121: Store data is invalid)

        404: Not Found - ErrorEntity (30141: Store [{storeId}] does not exist in namespace [{namespace}] | 30142: Published store does not exist in namespace [{namespace}])

        409: Conflict - ErrorEntity (30076: CSV header [{headerName}] is not supported for CatalogType [{catalogType}] | 30382: Duplicated Item sku [{sku}])

        ---: HttpResponse (Undocumented Response)

        ---: HttpResponse (Unexpected Content-Type Error)

        ---: HttpResponse (Unhandled Error)
        """
        pre_processed_response, error = self.pre_process_response(
            code=code, content_type=content_type, content=content
        )
        if error is not None:
            return None, None if error.is_no_content() else error
        code, content_type, content = pre_processed_response

        if code == 200:
            return ImportStoreResult.create_from_dict(content), None
        if code == 400:
            return None, ErrorEntity.create_from_dict(content)
        if code == 404:
            return None, ErrorEntity.create_from_dict(content)
        if code == 409:
            return None, ErrorEntity.create_from_dict(content)

        return self.handle_undocumented_response(
            code=code, content_type=content_type, content=content
        )

    # endregion response methods

    # region static methods

    @classmethod
    def create(
        cls,
        namespace: str,
        store_id: str,
        category: Optional[Any] = None,
        display: Optional[Any] = None,
        item: Optional[Any] = None,
        notes: Optional[str] = None,
        section: Optional[Any] = None,
        **kwargs,
    ) -> ImportStoreByCSV:
        instance = cls()
        instance.namespace = namespace
        instance.store_id = store_id
        if category is not None:
            instance.category = category
        if display is not None:
            instance.display = display
        if item is not None:
            instance.item = item
        if notes is not None:
            instance.notes = notes
        if section is not None:
            instance.section = section
        if x_flight_id := kwargs.get("x_flight_id", None):
            instance.x_flight_id = x_flight_id
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ImportStoreByCSV:
        instance = cls()
        if "category" in dict_ and dict_["category"] is not None:
            instance.category = Any(dict_["category"])
        elif include_empty:
            instance.category = Any()
        if "display" in dict_ and dict_["display"] is not None:
            instance.display = Any(dict_["display"])
        elif include_empty:
            instance.display = Any()
        if "item" in dict_ and dict_["item"] is not None:
            instance.item = Any(dict_["item"])
        elif include_empty:
            instance.item = Any()
        if "notes" in dict_ and dict_["notes"] is not None:
            instance.notes = str(dict_["notes"])
        elif include_empty:
            instance.notes = ""
        if "section" in dict_ and dict_["section"] is not None:
            instance.section = Any(dict_["section"])
        elif include_empty:
            instance.section = Any()
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if "storeId" in dict_ and dict_["storeId"] is not None:
            instance.store_id = str(dict_["storeId"])
        elif include_empty:
            instance.store_id = ""
        return instance

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "category": "category",
            "display": "display",
            "item": "item",
            "notes": "notes",
            "section": "section",
            "namespace": "namespace",
            "storeId": "store_id",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "category": False,
            "display": False,
            "item": False,
            "notes": False,
            "section": False,
            "namespace": True,
            "storeId": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# Fleet Commander

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from .utils import randomize

from ..api.ams.models import ApiAMSRegionsResponse
from ..api.ams.models import ApiAccountCreateRequest
from ..api.ams.models import ApiAccountCreateResponse
from ..api.ams.models import ApiAccountLimits
from ..api.ams.models import ApiAccountLinkRequest
from ..api.ams.models import ApiAccountLinkResponse
from ..api.ams.models import ApiAccountLinkTokenResponse
from ..api.ams.models import ApiAccountResponse
from ..api.ams.models import ApiArtifactListResponse
from ..api.ams.models import ApiArtifactResponse
from ..api.ams.models import ApiArtifactSamplingRule
from ..api.ams.models import ApiArtifactTypeSamplingRules
from ..api.ams.models import ApiArtifactURLResponse
from ..api.ams.models import ApiArtifactUsageResponse
from ..api.ams.models import ApiCapacity
from ..api.ams.models import ApiCoredumpSamplingRules
from ..api.ams.models import ApiDSHistoryEvent
from ..api.ams.models import ApiDSHistoryList
from ..api.ams.models import ApiDSHostConfiguration
from ..api.ams.models import ApiDSHostConfigurationParameters
from ..api.ams.models import ApiDevelopmentServerConfigurationCreateRequest
from ..api.ams.models import ApiDevelopmentServerConfigurationCreateResponse
from ..api.ams.models import ApiDevelopmentServerConfigurationGetResponse
from ..api.ams.models import ApiDevelopmentServerConfigurationListResponse
from ..api.ams.models import ApiDevelopmentServerConfigurationUpdateRequest
from ..api.ams.models import ApiFleetArtifactsSampleRules
from ..api.ams.models import ApiFleetBulkActionErrorItemResponse
from ..api.ams.models import ApiFleetBulkDeleteRequest
from ..api.ams.models import ApiFleetBulkDeleteResponse
from ..api.ams.models import ApiFleetClaimByKeysReq
from ..api.ams.models import ApiFleetClaimReq
from ..api.ams.models import ApiFleetClaimResponse
from ..api.ams.models import ApiFleetCreateResponse
from ..api.ams.models import ApiFleetGetResponse
from ..api.ams.models import ApiFleetListItemResponse
from ..api.ams.models import ApiFleetListResponse
from ..api.ams.models import ApiFleetParameters
from ..api.ams.models import ApiFleetRegionalServerCounts
from ..api.ams.models import ApiFleetServerConnectionInfoResponse
from ..api.ams.models import ApiFleetServerHistoryEventResponse
from ..api.ams.models import ApiFleetServerHistoryResponse
from ..api.ams.models import ApiFleetServerInfoResponse
from ..api.ams.models import ApiFleetServersResponse
from ..api.ams.models import ApiImageDeploymentProfile
from ..api.ams.models import ApiImageDetails
from ..api.ams.models import ApiImageList
from ..api.ams.models import ApiImageListItem
from ..api.ams.models import ApiImageStorage
from ..api.ams.models import ApiImageUpdate
from ..api.ams.models import ApiInstanceType
from ..api.ams.models import ApiInstanceTypesResponse
from ..api.ams.models import ApiPagingInfo
from ..api.ams.models import ApiPortConfiguration
from ..api.ams.models import ApiQoSEndpointResponse
from ..api.ams.models import ApiQoSServer
from ..api.ams.models import ApiReferencingFleet
from ..api.ams.models import ApiRegionConfig
from ..api.ams.models import ApiTimeout
from ..api.ams.models import ApiUpdateServerRequest
from ..api.ams.models import PaginationPaginationInfo
from ..api.ams.models import ResponseErrorResponse


def create_api_account_create_request_example() -> ApiAccountCreateRequest:
    instance = ApiAccountCreateRequest()
    instance.name = randomize()
    return instance


def create_api_account_create_response_example() -> ApiAccountCreateResponse:
    instance = ApiAccountCreateResponse()
    instance.id_ = randomize()
    instance.limits = create_api_account_limits_example()
    instance.name = randomize()
    instance.namespaces = [randomize()]
    return instance


def create_api_account_limits_example() -> ApiAccountLimits:
    instance = ApiAccountLimits()
    instance.allowed_node_classes = [randomize()]
    instance.allowed_regions = [randomize()]
    instance.fleet_count = randomize("int", min_val=1, max_val=1000)
    instance.fleet_vm_count = randomize("int", min_val=1, max_val=1000)
    instance.image_storage_quota_bytes = randomize("int", min_val=1, max_val=1000)
    return instance


def create_api_account_link_request_example() -> ApiAccountLinkRequest:
    instance = ApiAccountLinkRequest()
    instance.token = randomize()
    return instance


def create_api_account_link_response_example() -> ApiAccountLinkResponse:
    instance = ApiAccountLinkResponse()
    instance.id_ = randomize()
    instance.limits = create_api_account_limits_example()
    instance.name = randomize()
    instance.namespaces = [randomize()]
    return instance


def create_api_account_link_token_response_example() -> ApiAccountLinkTokenResponse:
    instance = ApiAccountLinkTokenResponse()
    instance.token = randomize()
    return instance


def create_api_account_response_example() -> ApiAccountResponse:
    instance = ApiAccountResponse()
    instance.id_ = randomize()
    instance.limits = create_api_account_limits_example()
    instance.name = randomize()
    instance.namespaces = [randomize()]
    return instance


def create_api_ams_regions_response_example() -> ApiAMSRegionsResponse:
    instance = ApiAMSRegionsResponse()
    instance.regions = [randomize()]
    return instance


def create_api_artifact_list_response_example() -> ApiArtifactListResponse:
    instance = ApiArtifactListResponse()
    instance.data = [create_api_artifact_response_example()]
    instance.total_data = randomize("int", min_val=1, max_val=1000)
    return instance


def create_api_artifact_response_example() -> ApiArtifactResponse:
    instance = ApiArtifactResponse()
    instance.artifact_type = randomize()
    instance.created_on = randomize("date")
    instance.ds_id = randomize()
    instance.expires_on = randomize("date")
    instance.filename = randomize()
    instance.fleet_id = randomize()
    instance.id_ = randomize()
    instance.image_id = randomize()
    instance.namespace = randomize("slug")
    instance.region = randomize()
    instance.size_bytes = randomize("int", min_val=1, max_val=1000)
    instance.status = randomize()
    instance.reason = randomize()
    return instance


def create_api_artifact_sampling_rule_example() -> ApiArtifactSamplingRule:
    instance = ApiArtifactSamplingRule()
    instance.collect = randomize("bool")
    instance.percentage = randomize("int", min_val=1, max_val=1000)
    return instance


def create_api_artifact_type_sampling_rules_example() -> ApiArtifactTypeSamplingRules:
    instance = ApiArtifactTypeSamplingRules()
    instance.crashed = create_api_artifact_sampling_rule_example()
    instance.success = create_api_artifact_sampling_rule_example()
    instance.unclaimed = create_api_artifact_sampling_rule_example()
    return instance


def create_api_artifact_url_response_example() -> ApiArtifactURLResponse:
    instance = ApiArtifactURLResponse()
    instance.url = randomize("url")
    return instance


def create_api_artifact_usage_response_example() -> ApiArtifactUsageResponse:
    instance = ApiArtifactUsageResponse()
    instance.quota_bytes = randomize("int", min_val=1, max_val=1000)
    instance.remaining_bytes = randomize("int", min_val=1, max_val=1000)
    instance.used_bytes = randomize("int", min_val=1, max_val=1000)
    return instance


def create_api_capacity_example() -> ApiCapacity:
    instance = ApiCapacity()
    instance.region = randomize()
    instance.vm_count = randomize("int", min_val=1, max_val=1000)
    return instance


def create_api_coredump_sampling_rules_example() -> ApiCoredumpSamplingRules:
    instance = ApiCoredumpSamplingRules()
    instance.crashed = create_api_artifact_sampling_rule_example()
    return instance


def create_api_development_server_configuration_create_request_example() -> (
    ApiDevelopmentServerConfigurationCreateRequest
):
    instance = ApiDevelopmentServerConfigurationCreateRequest()
    instance.command_line_arguments = randomize()
    instance.image_id = randomize()
    instance.name = randomize()
    instance.expires_at = randomize("date")
    return instance


def create_api_development_server_configuration_create_response_example() -> (
    ApiDevelopmentServerConfigurationCreateResponse
):
    instance = ApiDevelopmentServerConfigurationCreateResponse()
    instance.name = randomize()
    return instance


def create_api_development_server_configuration_get_response_example() -> (
    ApiDevelopmentServerConfigurationGetResponse
):
    instance = ApiDevelopmentServerConfigurationGetResponse()
    instance.command_line_arguments = randomize()
    instance.image_id = randomize()
    instance.name = randomize()
    instance.created_at = randomize("date")
    instance.expires_at = randomize("date")
    return instance


def create_api_development_server_configuration_list_response_example() -> (
    ApiDevelopmentServerConfigurationListResponse
):
    instance = ApiDevelopmentServerConfigurationListResponse()
    instance.data = [create_api_development_server_configuration_get_response_example()]
    instance.paging = create_pagination_pagination_info_example()
    instance.total_data = randomize("int", min_val=1, max_val=1000)
    return instance


def create_api_development_server_configuration_update_request_example() -> (
    ApiDevelopmentServerConfigurationUpdateRequest
):
    instance = ApiDevelopmentServerConfigurationUpdateRequest()
    instance.command_line_arguments = randomize()
    instance.expires_at = randomize("date")
    return instance


def create_api_ds_history_event_example() -> ApiDSHistoryEvent:
    instance = ApiDSHistoryEvent()
    instance.created_at = randomize("date")
    instance.exit_code = randomize("int", min_val=1, max_val=1000)
    instance.ip_address = randomize()
    instance.reason = randomize()
    instance.region = randomize()
    instance.server_id = randomize()
    instance.session_id = randomize("uid")
    instance.status = randomize()
    return instance


def create_api_ds_history_list_example() -> ApiDSHistoryList:
    instance = ApiDSHistoryList()
    instance.events = [create_api_ds_history_event_example()]
    instance.paging = create_api_paging_info_example()
    return instance


def create_api_ds_host_configuration_example() -> ApiDSHostConfiguration:
    instance = ApiDSHostConfiguration()
    instance.instance_id = randomize()
    instance.instance_provider = randomize()
    instance.instance_type = randomize()
    instance.servers_per_vm = randomize("int", min_val=1, max_val=1000)
    return instance


def create_api_ds_host_configuration_parameters_example() -> (
    ApiDSHostConfigurationParameters
):
    instance = ApiDSHostConfigurationParameters()
    instance.instance_id = randomize()
    instance.servers_per_vm = randomize("int", min_val=1, max_val=1000)
    return instance


def create_api_fleet_artifacts_sample_rules_example() -> ApiFleetArtifactsSampleRules:
    instance = ApiFleetArtifactsSampleRules()
    instance.coredumps = create_api_coredump_sampling_rules_example()
    instance.logs = create_api_artifact_type_sampling_rules_example()
    return instance


def create_api_fleet_bulk_action_error_item_response_example() -> (
    ApiFleetBulkActionErrorItemResponse
):
    instance = ApiFleetBulkActionErrorItemResponse()
    instance.fleet_id = randomize()
    instance.error_message = randomize()
    instance.error_type = randomize()
    return instance


def create_api_fleet_bulk_delete_request_example() -> ApiFleetBulkDeleteRequest:
    instance = ApiFleetBulkDeleteRequest()
    instance.fleet_ids = [randomize()]
    return instance


def create_api_fleet_bulk_delete_response_example() -> ApiFleetBulkDeleteResponse:
    instance = ApiFleetBulkDeleteResponse()
    instance.errors = [create_api_fleet_bulk_action_error_item_response_example()]
    instance.success_count = randomize("int", min_val=1, max_val=1000)
    instance.total_count = randomize("int", min_val=1, max_val=1000)
    return instance


def create_api_fleet_claim_by_keys_req_example() -> ApiFleetClaimByKeysReq:
    instance = ApiFleetClaimByKeysReq()
    instance.claim_keys = [randomize()]
    instance.regions = [randomize()]
    instance.session_id = randomize("uid")
    return instance


def create_api_fleet_claim_req_example() -> ApiFleetClaimReq:
    instance = ApiFleetClaimReq()
    instance.region = randomize()
    instance.session_id = randomize("uid")
    return instance


def create_api_fleet_claim_response_example() -> ApiFleetClaimResponse:
    instance = ApiFleetClaimResponse()
    instance.fleet_id = randomize()
    instance.ip = randomize()
    instance.ports = {}
    instance.region = randomize()
    instance.server_id = randomize()
    return instance


def create_api_fleet_create_response_example() -> ApiFleetCreateResponse:
    instance = ApiFleetCreateResponse()
    instance.id_ = randomize()
    return instance


def create_api_fleet_get_response_example() -> ApiFleetGetResponse:
    instance = ApiFleetGetResponse()
    instance.active = randomize("bool")
    instance.claim_keys = [randomize()]
    instance.ds_host_configuration = create_api_ds_host_configuration_example()
    instance.fallback_fleet = randomize()
    instance.id_ = randomize()
    instance.image_deployment_profile = create_api_image_deployment_profile_example()
    instance.is_local = randomize("bool")
    instance.name = randomize()
    instance.on_demand = randomize("bool")
    instance.primary_fleet = randomize()
    instance.regions = [create_api_region_config_example()]
    instance.sampling_rules = create_api_fleet_artifacts_sample_rules_example()
    instance.hibernate_after_period = randomize()
    return instance


def create_api_fleet_list_item_response_example() -> ApiFleetListItemResponse:
    instance = ApiFleetListItemResponse()
    instance.active = randomize("bool")
    instance.counts = [create_api_fleet_regional_server_counts_example()]
    instance.fallback_fleet = randomize()
    instance.id_ = randomize()
    instance.image = randomize()
    instance.instance_provider = randomize()
    instance.is_local = randomize("bool")
    instance.name = randomize()
    instance.on_demand = randomize("bool")
    instance.primary_fleet = randomize()
    instance.regions = [randomize()]
    return instance


def create_api_fleet_list_response_example() -> ApiFleetListResponse:
    instance = ApiFleetListResponse()
    instance.fleets = [create_api_fleet_list_item_response_example()]
    instance.paging = create_pagination_pagination_info_example()
    return instance


def create_api_fleet_parameters_example() -> ApiFleetParameters:
    instance = ApiFleetParameters()
    instance.active = randomize("bool")
    instance.ds_host_configuration = (
        create_api_ds_host_configuration_parameters_example()
    )
    instance.image_deployment_profile = create_api_image_deployment_profile_example()
    instance.name = randomize()
    instance.on_demand = randomize("bool")
    instance.regions = [create_api_region_config_example()]
    instance.claim_keys = [randomize()]
    instance.fallback_fleet = randomize()
    instance.hibernate_after_period = randomize()
    instance.sampling_rules = create_api_fleet_artifacts_sample_rules_example()
    return instance


def create_api_fleet_regional_server_counts_example() -> ApiFleetRegionalServerCounts:
    instance = ApiFleetRegionalServerCounts()
    instance.claimed_server_count = randomize("int", min_val=1, max_val=1000)
    instance.ready_server_count = randomize("int", min_val=1, max_val=1000)
    instance.region = randomize()
    instance.running_vm_count = randomize("int", min_val=1, max_val=1000)
    instance.target_ds_count = randomize("int", min_val=1, max_val=1000)
    instance.target_vm_count = randomize("int", min_val=1, max_val=1000)
    return instance


def create_api_fleet_server_connection_info_response_example() -> (
    ApiFleetServerConnectionInfoResponse
):
    instance = ApiFleetServerConnectionInfoResponse()
    instance.expires_at = randomize("date")
    instance.host = randomize()
    instance.logstream_port = randomize("int", min_val=1, max_val=1000)
    instance.secret = randomize()
    return instance


def create_api_fleet_server_history_event_response_example() -> (
    ApiFleetServerHistoryEventResponse
):
    instance = ApiFleetServerHistoryEventResponse()
    instance.created_at = randomize("date")
    instance.exit_code = randomize("int", min_val=1, max_val=1000)
    instance.fleet_id = randomize()
    instance.new_state = randomize()
    instance.old_state = randomize()
    instance.reason = randomize()
    instance.server_id = randomize()
    return instance


def create_api_fleet_server_history_response_example() -> ApiFleetServerHistoryResponse:
    instance = ApiFleetServerHistoryResponse()
    instance.events = [create_api_fleet_server_history_event_response_example()]
    return instance


def create_api_fleet_server_info_response_example() -> ApiFleetServerInfoResponse:
    instance = ApiFleetServerInfoResponse()
    instance.created_at = randomize("date")
    instance.fleet_id = randomize()
    instance.fleet_name = randomize()
    instance.image_cmd = randomize()
    instance.image_id = randomize()
    instance.instance_type = randomize()
    instance.ip_address = randomize()
    instance.port_configuration = [create_api_port_configuration_example()]
    instance.ports = {}
    instance.region = randomize()
    instance.server_configuration = randomize()
    instance.server_id = randomize()
    instance.session_id = randomize("uid")
    instance.status = randomize()
    return instance


def create_api_fleet_servers_response_example() -> ApiFleetServersResponse:
    instance = ApiFleetServersResponse()
    instance.paging = create_api_paging_info_example()
    instance.regions = [create_api_fleet_regional_server_counts_example()]
    instance.servers = [create_api_fleet_server_info_response_example()]
    return instance


def create_api_image_deployment_profile_example() -> ApiImageDeploymentProfile:
    instance = ApiImageDeploymentProfile()
    instance.command_line = randomize()
    instance.image_id = randomize()
    instance.port_configurations = [create_api_port_configuration_example()]
    instance.timeout = create_api_timeout_example()
    return instance


def create_api_image_details_example() -> ApiImageDetails:
    instance = ApiImageDetails()
    instance.created_at = randomize("date")
    instance.executable = randomize()
    instance.id_ = randomize()
    instance.is_protected = randomize("bool")
    instance.name = randomize()
    instance.referencing_fleets = [create_api_referencing_fleet_example()]
    instance.size_in_byte = randomize("int", min_val=1, max_val=1000)
    instance.status = randomize()
    instance.tags = [randomize()]
    instance.target_architecture = randomize()
    instance.uploaded_at = randomize("date")
    instance.uploaded_by = randomize()
    instance.delete_at = randomize()
    return instance


def create_api_image_list_example() -> ApiImageList:
    instance = ApiImageList()
    instance.images = [create_api_image_list_item_example()]
    instance.paging = create_api_paging_info_example()
    return instance


def create_api_image_list_item_example() -> ApiImageListItem:
    instance = ApiImageListItem()
    instance.created_at = randomize("date")
    instance.executable = randomize()
    instance.id_ = randomize()
    instance.is_protected = randomize("bool")
    instance.name = randomize()
    instance.referencing_configs = randomize("int", min_val=1, max_val=1000)
    instance.referencing_fleets = randomize("int", min_val=1, max_val=1000)
    instance.size_in_byte = randomize("int", min_val=1, max_val=1000)
    instance.status = randomize()
    instance.tags = [randomize()]
    instance.target_architecture = randomize()
    instance.uploaded_at = randomize("date")
    instance.uploaded_by = randomize()
    instance.delete_at = randomize()
    return instance


def create_api_image_storage_example() -> ApiImageStorage:
    instance = ApiImageStorage()
    instance.current_marked_for_deletion_bytes = randomize(
        "int", min_val=1, max_val=1000
    )
    instance.current_usage_bytes = randomize("int", min_val=1, max_val=1000)
    instance.quota_bytes = randomize("int", min_val=1, max_val=1000)
    return instance


def create_api_image_update_example() -> ApiImageUpdate:
    instance = ApiImageUpdate()
    instance.added_tags = [randomize()]
    instance.removed_tags = [randomize()]
    instance.is_protected = randomize("bool")
    instance.name = randomize()
    return instance


def create_api_instance_type_example() -> ApiInstanceType:
    instance = ApiInstanceType()
    instance.capacity = [create_api_capacity_example()]
    instance.description = randomize()
    instance.id_ = randomize()
    instance.is_baremetal = randomize("bool")
    instance.memory_gi_b = randomize("int", min_val=1, max_val=1000)
    instance.min_speed = randomize()
    instance.name = randomize()
    instance.owner_account_id = randomize()
    instance.processor_architecture = randomize()
    instance.provider = randomize()
    instance.virtual_cpu = randomize("int", min_val=1, max_val=1000)
    return instance


def create_api_instance_types_response_example() -> ApiInstanceTypesResponse:
    instance = ApiInstanceTypesResponse()
    instance.available_instance_types = [create_api_instance_type_example()]
    return instance


def create_api_paging_info_example() -> ApiPagingInfo:
    instance = ApiPagingInfo()
    instance.current_page = randomize("int", min_val=1, max_val=1000)
    instance.has_next = randomize("bool")
    instance.has_pages = randomize("bool")
    instance.has_prev = randomize("bool")
    instance.next_ = randomize()
    instance.page_nums = [randomize("int", min_val=1, max_val=1000)]
    instance.previous = randomize()
    instance.total = randomize("int", min_val=1, max_val=1000)
    return instance


def create_api_port_configuration_example() -> ApiPortConfiguration:
    instance = ApiPortConfiguration()
    instance.name = randomize()
    instance.protocol = randomize()
    return instance


def create_api_qo_s_endpoint_response_example() -> ApiQoSEndpointResponse:
    instance = ApiQoSEndpointResponse()
    instance.servers = [create_api_qo_s_server_example()]
    return instance


def create_api_qo_s_server_example() -> ApiQoSServer:
    instance = ApiQoSServer()
    instance.alias = randomize()
    instance.ip = randomize()
    instance.last_update = randomize("date")
    instance.port = randomize("int", min_val=1, max_val=1000)
    instance.region = randomize()
    instance.status = randomize()
    return instance


def create_api_referencing_fleet_example() -> ApiReferencingFleet:
    instance = ApiReferencingFleet()
    instance.environment = randomize()
    instance.fleet_id = randomize()
    instance.namespace = randomize("slug")
    return instance


def create_api_region_config_example() -> ApiRegionConfig:
    instance = ApiRegionConfig()
    instance.buffer_size = randomize("int", min_val=1, max_val=1000)
    instance.dynamic_buffer = randomize("bool")
    instance.max_server_count = randomize("int", min_val=1, max_val=1000)
    instance.min_server_count = randomize("int", min_val=1, max_val=1000)
    instance.region = randomize()
    instance.state = randomize()
    return instance


def create_api_timeout_example() -> ApiTimeout:
    instance = ApiTimeout()
    instance.claim = randomize("int", min_val=1, max_val=1000)
    instance.creation = randomize("int", min_val=1, max_val=1000)
    instance.drain = randomize("int", min_val=1, max_val=1000)
    instance.session = randomize("int", min_val=1, max_val=1000)
    instance.unresponsive = randomize("int", min_val=1, max_val=1000)
    return instance


def create_api_update_server_request_example() -> ApiUpdateServerRequest:
    instance = ApiUpdateServerRequest()
    instance.status = randomize()
    return instance


def create_pagination_pagination_info_example() -> PaginationPaginationInfo:
    instance = PaginationPaginationInfo()
    instance.first = randomize()
    instance.last = randomize()
    instance.next_ = randomize()
    instance.previous = randomize()
    instance.total = randomize("int", min_val=1, max_val=1000)
    return instance


def create_response_error_response_example() -> ResponseErrorResponse:
    instance = ResponseErrorResponse()
    instance.error_message = randomize()
    instance.error_type = randomize()
    instance.trace_id = randomize()
    return instance



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import deprecated
from ....core import same_doc_as

from ..models import RetrieveUserInfoCacheStatusResponse

from ..operations.user_info import GetUserInfoStatus
from ..operations.user_info import InvalidateUserInfoCache
from ..operations.user_info import SyncUserInfo


@deprecated
@same_doc_as(GetUserInfoStatus)
def get_user_info_status(
    namespaces: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get user info cache status (getUserInfoStatus)

    Get user info cache last updated time per namespace.
    The query parameter namespaces can be a list of namespace separated by comma.
    If query parameter namespaces is empty, user info cache status for all available namespaces will be returned.

    Properties:
        url: /agreement/admin/userInfo

        method: GET

        tags: ["UserInfo"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespaces: (namespaces) OPTIONAL str in query

    Responses:
        200: OK - List[RetrieveUserInfoCacheStatusResponse] (successful operation)
    """
    request = GetUserInfoStatus.create(
        namespaces=namespaces,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(GetUserInfoStatus)
async def get_user_info_status_async(
    namespaces: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get user info cache status (getUserInfoStatus)

    Get user info cache last updated time per namespace.
    The query parameter namespaces can be a list of namespace separated by comma.
    If query parameter namespaces is empty, user info cache status for all available namespaces will be returned.

    Properties:
        url: /agreement/admin/userInfo

        method: GET

        tags: ["UserInfo"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespaces: (namespaces) OPTIONAL str in query

    Responses:
        200: OK - List[RetrieveUserInfoCacheStatusResponse] (successful operation)
    """
    request = GetUserInfoStatus.create(
        namespaces=namespaces,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@deprecated
@same_doc_as(InvalidateUserInfoCache)
def invalidate_user_info_cache(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Invalidate user info cache (invalidateUserInfoCache)

    Invalidate user info cache in agreement service.

    Properties:
        url: /agreement/admin/userInfo

        method: DELETE

        tags: ["UserInfo"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) OPTIONAL str in query

    Responses:
        204: No Content - (Successful operation)
    """
    request = InvalidateUserInfoCache.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(InvalidateUserInfoCache)
async def invalidate_user_info_cache_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Invalidate user info cache (invalidateUserInfoCache)

    Invalidate user info cache in agreement service.

    Properties:
        url: /agreement/admin/userInfo

        method: DELETE

        tags: ["UserInfo"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) OPTIONAL str in query

    Responses:
        204: No Content - (Successful operation)
    """
    request = InvalidateUserInfoCache.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@deprecated
@same_doc_as(SyncUserInfo)
def sync_user_info(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Sync user info with iam service  (syncUserInfo)

    Sync user info cache in agreement service with iam service.

    Properties:
        url: /agreement/admin/userInfo

        method: PUT

        tags: ["UserInfo"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in query

    Responses:
        200: OK - (Successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = SyncUserInfo.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@deprecated
@same_doc_as(SyncUserInfo)
async def sync_user_info_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Sync user info with iam service  (syncUserInfo)

    Sync user info cache in agreement service with iam service.

    Properties:
        url: /agreement/admin/userInfo

        method: PUT

        tags: ["UserInfo"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in query

    Responses:
        200: OK - (Successful operation)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = SyncUserInfo.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Session Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model
from ....core import StrEnum


class PSNDisableSystemUIMenuEnum(StrEnum):
    KICK = "KICK"
    PROMOTE_TO_LEADER = "PROMOTE_TO_LEADER"
    UPDATE_INVITABLE_USER_TYPE = "UPDATE_INVITABLE_USER_TYPE"
    UPDATE_JOINABLE_USER_TYPE = "UPDATE_JOINABLE_USER_TYPE"


class ModelsNativeSessionSetting(Model):
    """Models native session setting (models.NativeSessionSetting)

    Properties:
        psn_service_label: (PSNServiceLabel) REQUIRED int

        session_title: (SessionTitle) REQUIRED str

        xbox_allow_cross_platform: (XboxAllowCrossPlatform) REQUIRED bool

        xbox_sandbox_id: (XboxSandboxID) REQUIRED str

        xbox_service_config_id: (XboxServiceConfigID) REQUIRED str

        xbox_session_template_name: (XboxSessionTemplateName) REQUIRED str

        xbox_title_id: (XboxTitleID) REQUIRED str

        active_platforms: (activePlatforms) OPTIONAL List[str]

        localized_session_name: (localizedSessionName) OPTIONAL Dict[str, Any]

        psn_disable_system_ui_menu: (PSNDisableSystemUIMenu) OPTIONAL List[Union[str, PSNDisableSystemUIMenuEnum]]

        psn_supported_platforms: (PSNSupportedPlatforms) OPTIONAL List[str]

        should_sync: (ShouldSync) OPTIONAL bool
    """

    # region fields

    psn_service_label: int  # REQUIRED
    session_title: str  # REQUIRED
    xbox_allow_cross_platform: bool  # REQUIRED
    xbox_sandbox_id: str  # REQUIRED
    xbox_service_config_id: str  # REQUIRED
    xbox_session_template_name: str  # REQUIRED
    xbox_title_id: str  # REQUIRED
    active_platforms: List[str]  # OPTIONAL
    localized_session_name: Dict[str, Any]  # OPTIONAL
    psn_disable_system_ui_menu: List[Union[str, PSNDisableSystemUIMenuEnum]]  # OPTIONAL
    psn_supported_platforms: List[str]  # OPTIONAL
    should_sync: bool  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_psn_service_label(self, value: int) -> ModelsNativeSessionSetting:
        self.psn_service_label = value
        return self

    def with_session_title(self, value: str) -> ModelsNativeSessionSetting:
        self.session_title = value
        return self

    def with_xbox_allow_cross_platform(self, value: bool) -> ModelsNativeSessionSetting:
        self.xbox_allow_cross_platform = value
        return self

    def with_xbox_sandbox_id(self, value: str) -> ModelsNativeSessionSetting:
        self.xbox_sandbox_id = value
        return self

    def with_xbox_service_config_id(self, value: str) -> ModelsNativeSessionSetting:
        self.xbox_service_config_id = value
        return self

    def with_xbox_session_template_name(self, value: str) -> ModelsNativeSessionSetting:
        self.xbox_session_template_name = value
        return self

    def with_xbox_title_id(self, value: str) -> ModelsNativeSessionSetting:
        self.xbox_title_id = value
        return self

    def with_active_platforms(self, value: List[str]) -> ModelsNativeSessionSetting:
        self.active_platforms = value
        return self

    def with_localized_session_name(
        self, value: Dict[str, Any]
    ) -> ModelsNativeSessionSetting:
        self.localized_session_name = value
        return self

    def with_psn_disable_system_ui_menu(
        self, value: List[Union[str, PSNDisableSystemUIMenuEnum]]
    ) -> ModelsNativeSessionSetting:
        self.psn_disable_system_ui_menu = value
        return self

    def with_psn_supported_platforms(
        self, value: List[str]
    ) -> ModelsNativeSessionSetting:
        self.psn_supported_platforms = value
        return self

    def with_should_sync(self, value: bool) -> ModelsNativeSessionSetting:
        self.should_sync = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "psn_service_label"):
            result["PSNServiceLabel"] = int(self.psn_service_label)
        elif include_empty:
            result["PSNServiceLabel"] = 0
        if hasattr(self, "session_title"):
            result["SessionTitle"] = str(self.session_title)
        elif include_empty:
            result["SessionTitle"] = ""
        if hasattr(self, "xbox_allow_cross_platform"):
            result["XboxAllowCrossPlatform"] = bool(self.xbox_allow_cross_platform)
        elif include_empty:
            result["XboxAllowCrossPlatform"] = False
        if hasattr(self, "xbox_sandbox_id"):
            result["XboxSandboxID"] = str(self.xbox_sandbox_id)
        elif include_empty:
            result["XboxSandboxID"] = ""
        if hasattr(self, "xbox_service_config_id"):
            result["XboxServiceConfigID"] = str(self.xbox_service_config_id)
        elif include_empty:
            result["XboxServiceConfigID"] = ""
        if hasattr(self, "xbox_session_template_name"):
            result["XboxSessionTemplateName"] = str(self.xbox_session_template_name)
        elif include_empty:
            result["XboxSessionTemplateName"] = ""
        if hasattr(self, "xbox_title_id"):
            result["XboxTitleID"] = str(self.xbox_title_id)
        elif include_empty:
            result["XboxTitleID"] = ""
        if hasattr(self, "active_platforms"):
            result["activePlatforms"] = [str(i0) for i0 in self.active_platforms]
        elif include_empty:
            result["activePlatforms"] = []
        if hasattr(self, "localized_session_name"):
            result["localizedSessionName"] = {
                str(k0): v0 for k0, v0 in self.localized_session_name.items()
            }
        elif include_empty:
            result["localizedSessionName"] = {}
        if hasattr(self, "psn_disable_system_ui_menu"):
            result["PSNDisableSystemUIMenu"] = [
                str(i0) for i0 in self.psn_disable_system_ui_menu
            ]
        elif include_empty:
            result["PSNDisableSystemUIMenu"] = []
        if hasattr(self, "psn_supported_platforms"):
            result["PSNSupportedPlatforms"] = [
                str(i0) for i0 in self.psn_supported_platforms
            ]
        elif include_empty:
            result["PSNSupportedPlatforms"] = []
        if hasattr(self, "should_sync"):
            result["ShouldSync"] = bool(self.should_sync)
        elif include_empty:
            result["ShouldSync"] = False
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        psn_service_label: int,
        session_title: str,
        xbox_allow_cross_platform: bool,
        xbox_sandbox_id: str,
        xbox_service_config_id: str,
        xbox_session_template_name: str,
        xbox_title_id: str,
        active_platforms: Optional[List[str]] = None,
        localized_session_name: Optional[Dict[str, Any]] = None,
        psn_disable_system_ui_menu: Optional[
            List[Union[str, PSNDisableSystemUIMenuEnum]]
        ] = None,
        psn_supported_platforms: Optional[List[str]] = None,
        should_sync: Optional[bool] = None,
        **kwargs,
    ) -> ModelsNativeSessionSetting:
        instance = cls()
        instance.psn_service_label = psn_service_label
        instance.session_title = session_title
        instance.xbox_allow_cross_platform = xbox_allow_cross_platform
        instance.xbox_sandbox_id = xbox_sandbox_id
        instance.xbox_service_config_id = xbox_service_config_id
        instance.xbox_session_template_name = xbox_session_template_name
        instance.xbox_title_id = xbox_title_id
        if active_platforms is not None:
            instance.active_platforms = active_platforms
        if localized_session_name is not None:
            instance.localized_session_name = localized_session_name
        if psn_disable_system_ui_menu is not None:
            instance.psn_disable_system_ui_menu = psn_disable_system_ui_menu
        if psn_supported_platforms is not None:
            instance.psn_supported_platforms = psn_supported_platforms
        if should_sync is not None:
            instance.should_sync = should_sync
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelsNativeSessionSetting:
        instance = cls()
        if not dict_:
            return instance
        if "PSNServiceLabel" in dict_ and dict_["PSNServiceLabel"] is not None:
            instance.psn_service_label = int(dict_["PSNServiceLabel"])
        elif include_empty:
            instance.psn_service_label = 0
        if "SessionTitle" in dict_ and dict_["SessionTitle"] is not None:
            instance.session_title = str(dict_["SessionTitle"])
        elif include_empty:
            instance.session_title = ""
        if (
            "XboxAllowCrossPlatform" in dict_
            and dict_["XboxAllowCrossPlatform"] is not None
        ):
            instance.xbox_allow_cross_platform = bool(dict_["XboxAllowCrossPlatform"])
        elif include_empty:
            instance.xbox_allow_cross_platform = False
        if "XboxSandboxID" in dict_ and dict_["XboxSandboxID"] is not None:
            instance.xbox_sandbox_id = str(dict_["XboxSandboxID"])
        elif include_empty:
            instance.xbox_sandbox_id = ""
        if "XboxServiceConfigID" in dict_ and dict_["XboxServiceConfigID"] is not None:
            instance.xbox_service_config_id = str(dict_["XboxServiceConfigID"])
        elif include_empty:
            instance.xbox_service_config_id = ""
        if (
            "XboxSessionTemplateName" in dict_
            and dict_["XboxSessionTemplateName"] is not None
        ):
            instance.xbox_session_template_name = str(dict_["XboxSessionTemplateName"])
        elif include_empty:
            instance.xbox_session_template_name = ""
        if "XboxTitleID" in dict_ and dict_["XboxTitleID"] is not None:
            instance.xbox_title_id = str(dict_["XboxTitleID"])
        elif include_empty:
            instance.xbox_title_id = ""
        if "activePlatforms" in dict_ and dict_["activePlatforms"] is not None:
            instance.active_platforms = [str(i0) for i0 in dict_["activePlatforms"]]
        elif include_empty:
            instance.active_platforms = []
        if (
            "localizedSessionName" in dict_
            and dict_["localizedSessionName"] is not None
        ):
            instance.localized_session_name = {
                str(k0): v0 for k0, v0 in dict_["localizedSessionName"].items()
            }
        elif include_empty:
            instance.localized_session_name = {}
        if (
            "PSNDisableSystemUIMenu" in dict_
            and dict_["PSNDisableSystemUIMenu"] is not None
        ):
            instance.psn_disable_system_ui_menu = [
                str(i0) for i0 in dict_["PSNDisableSystemUIMenu"]
            ]
        elif include_empty:
            instance.psn_disable_system_ui_menu = []
        if (
            "PSNSupportedPlatforms" in dict_
            and dict_["PSNSupportedPlatforms"] is not None
        ):
            instance.psn_supported_platforms = [
                str(i0) for i0 in dict_["PSNSupportedPlatforms"]
            ]
        elif include_empty:
            instance.psn_supported_platforms = []
        if "ShouldSync" in dict_ and dict_["ShouldSync"] is not None:
            instance.should_sync = bool(dict_["ShouldSync"])
        elif include_empty:
            instance.should_sync = False
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelsNativeSessionSetting]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelsNativeSessionSetting]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelsNativeSessionSetting,
        List[ModelsNativeSessionSetting],
        Dict[Any, ModelsNativeSessionSetting],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "PSNServiceLabel": "psn_service_label",
            "SessionTitle": "session_title",
            "XboxAllowCrossPlatform": "xbox_allow_cross_platform",
            "XboxSandboxID": "xbox_sandbox_id",
            "XboxServiceConfigID": "xbox_service_config_id",
            "XboxSessionTemplateName": "xbox_session_template_name",
            "XboxTitleID": "xbox_title_id",
            "activePlatforms": "active_platforms",
            "localizedSessionName": "localized_session_name",
            "PSNDisableSystemUIMenu": "psn_disable_system_ui_menu",
            "PSNSupportedPlatforms": "psn_supported_platforms",
            "ShouldSync": "should_sync",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "PSNServiceLabel": True,
            "SessionTitle": True,
            "XboxAllowCrossPlatform": True,
            "XboxSandboxID": True,
            "XboxServiceConfigID": True,
            "XboxSessionTemplateName": True,
            "XboxTitleID": True,
            "activePlatforms": False,
            "localizedSessionName": False,
            "PSNDisableSystemUIMenu": False,
            "PSNSupportedPlatforms": False,
            "ShouldSync": False,
        }

    @staticmethod
    def get_enum_map() -> Dict[str, List[Any]]:
        return {
            "PSNDisableSystemUIMenu": [
                "KICK",
                "PROMOTE_TO_LEADER",
                "UPDATE_INVITABLE_USER_TYPE",
                "UPDATE_JOINABLE_USER_TYPE",
            ],
        }

    # endregion static methods
